% Ampli.m  Companion program to amplification.m (see that m-file for explanation)
% CD-ROM version
% The present version of the program allows you to use either:
%             1)  cross_cut
%             2)  cross_cut_fast
% Also the detailed plots at each x-station that were provided in amplification have
% been removed in the present version.Therefore it is advised that when you experience
% problems with ampli.m you rerun the case with the extensive version.
% -------------------------------------------------------------------------------------
clear
close all
global ...
ArMaxMaxT ArlogRtcrit r_grid Tbar Tss  domega_saved logFax ... 
logMaxMaxT_vs_logcrit_spline logcrit_vs_logH_spline rtop_vs_logcrit_spline ... 
scale_domega_vs_logcrit_spline  slope_left_vs_logcrit_spline ...
ArNumberofReynolds ArH Arscomega Arr omega_Arnal T_Arnal ome_ax fnr ri ...
logcriti log_Ftop_spline TMax TMaxMax omega_at_axis scomega  coefs_log_Ftop ...
coefs_log_MaxMaxT   coefs_scale coefs_rtop  coefs_slope_left ...
coefs_logcrit_vs_logH  pp_overall_left  pp_overall_right    
% ----------------------------------  end global  ------------------------------------
load datafile_for_n_factor
% -----------------------
disp ('You may use two various versions of "cross_cut"              ')
disp ('1=The extensive one                                          ')
disp ('2=The fast approximate one                                   ')
version_cross=input('give your choice   ')
hold off
freqs=[-7 -1  601];% This is a rather wide range of frequencies. For practical
% applications you may want to reduce this range and/or the 
% number of frequencies within that range after having built up experience with
% the method.Just observe the detailed plots.  
f1=freqs(1);
f2=freqs(2);
fnr=freqs(3);
Finf=logspace(f1,f2,fnr);
xfr=[1:fnr];
% The N-factor calculations should be done for constant values of omega, 
% that is constant Finf=omega*nu/Uinf^2 . Other researchers have used for convenience 
% constant F=omega*nu/U^2
% Our experience has shown that the final results show negligible differences
% because we use the envelope for a large number of frequencies.
% We will always use the first option.
% -------------------------------------------------------------------------------------
disp('------------------------------------------------ ----')
disp('       You have a choice from various cases          ')
disp('       1=PhD case van Ingen                          ')
disp('       2=flat plate                                  ')
disp('       3=flat plate with oscillating H superimposed  ')
disp('       4=flat plate with reduced H-region            ')
disp('       5=Rheinboldt 1.0                              ')
disp('       6=Iglisch                                     ')
disp('       7=simulated rooftop airfoil                   ')
disp('       8=you may add your own cases here             ')
disp('-----------------------------------------------------')
my_choice=input('give the number of your choice;  1<=number<=7   ') 
% ------------------------------------------------------------------------------------
% Call here the m-file to prepare x,U,H,R-theta 
% Use arrays xarr,Uarr,Harr and Rt_arr respectively
% Also give the chord Reynolds number as Rcred,that is leave out a factor 1E6 
% -------------------------------- choice=1 ------------------------------------------
if my_choice==1
   load results_PhD_case % for explanation see chapter 12 of report
   xarr=xtemp(1:stop_station);
   Rt_arr=Rtetatemp(1:stop_station);
   Harr=bightemp(1:stop_station);
   Uarr=Utemp(1:stop_station);
   Rcred=Rc*1E-6;
end % end choice 1
%  -----------------------------  choice=2  ----------------------------------------
if my_choice==2
   xarr=[0:.001:.05  .06:.01:1 ] ;% We take small steps near x=0 so that we can
   lx=length(xarr);               % safely take Re_theta(1)=.1*Re_theta(2) to avoid
   Uarr=ones(1,lx);               % problems with Log if Re_theta(1)=0
   Harr=2.591*ones(1,lx); 
   Rcred=10;
   rootRcred=sqrt(Rcred);
   Rt_arr=664*rootRcred*sqrt(xarr);
end % end choice 2
%  ----------------------------  choice==3  --------------------------------------- 
if my_choice==3
   % we put a sinusoidal oscillation on H for the flat plate to see the effect on 
   % the n-factor. Just to keep it simple Re-theta is taken equal to the standard
   % flat plate case with H=constant=2.591
   % Note that in many cases the effect of pressure gradient and/or suction 
   % on the n-factor is mostly through H and not through Re-theta 
   xarr=[0:.001:.05  .06:.01:1 ] ;% Same as for choice 2
   lx=length(xarr);
   Uarr=ones(1,lx);
   H0=2.591
   dH=input('give dH, may be >= or < 0 a good choice is +.2 or -.2       ')
   Harr=H0*ones(1,lx);
   Rcred=10; rootRcred=sqrt(Rcred);
   Rt_arr=664*rootRcred*sqrt(xarr);
   station1=96; station2=lx;
   x1=xarr(station1);
   x2=xarr(station2);
   d=2*pi/(x2-x1);
   Harr(station1:station2)=H0+dH*sin(d*(xarr(station1:station2)-x1));
end % end choice 3
% ----------------------------------   choice=4   -------------------------------
if my_choice==4
   % we put a low H-region between x/c=.2 and .5;just to keep it simple R-theta is 
   % taken equal to that for H=constant as in choice 5
   xarr=[0:.001:.05  .06:.01:1 ] ;% Same as for choice 2 and 3
   lx=length(xarr);
   Uarr=ones(1,lx);
   H0=2.591
   Harr=H0*ones(1,lx);
   Rcred=10; rootRcred=sqrt(Rcred);
   Rt_arr=664*rootRcred*sqrt(xarr);
   station1=66; station2=96;
   x1=xarr(station1);
   x2=xarr(station2);
   dH=input('give dH=dip in H; .3 is a good example');
   temp=dH/.15^2;
   Harr(station1:station2)=H0-dH+temp*(xarr(station1:station2)-xarr(81)).^2;
end  % end choice 4
% ---------------------------------- choice=5  ----------------------------
if my_choice==5
   load results_Rheinb   % for explanation see chapter 12 of the report
   xarr=x;
   Harr=bigh;
   Rt_arr=Rteta;
   Uarr=U;
end  % end choice 5
% -------------------------------------choice=6 ---------------------------------------
if my_choice==6
   load results_Iglisch_501_10  
                             % Results from a finite difference boundary layer
                             % calculation with 501 points across the boundary layer
                             % and 10 iterations per x-step
                             % contains rootx from 0 to 3, teta,tau,bigh,Iglischtable
                             % rootx_plot (127 values from 0 to 1), H_plot and theta_plot
                             % also an array with earlier calculated N-values to be used 
                             % in a separate program (see report)                   
                             % note that xarr = cq^2 * U*x/nu and because cq is of the 
                             % order 1E-4 Reynolds-x is very soon of the order 1E8. 
   xarr=rootx_plot.^2;
   xforplot=rootx_plot;
   Harr=H_plot;
   last_station=length(xarr);    % =127
   Uarr=ones(1,last_station);
   % ----------------------------------------------------------------------------------
   disp('you will be asked to input cqred=cq*1E4           ')
   disp('good examples are .5 and 1.5                      ')
   disp('For .5 the N-factor will exceed 10; for 1.5 there will be complete stability')
   cqred=input('give cq*1E4       ')
   cq=.0001*cqred;
   Rc=cq^-2;
   Rt_arr=theta_plot.*rootx_plot/cq;
   Rcred=Rc*1E-6;
end % end choice 6 (Iglisch)
% --------------------------------------choice=7 ------------------------------------
if my_choice==7
   % we take a flat plate for 0<=x<=.5 and let H linearly increase from the 
   % flat plate value at x=.5 to H_end at x=1
   % just to keep it simple Re-theta is taken equal to that for the flat plate
   % as in previous examples
   xarr=[0:.001:.05  .06:.01:1 ]; 
   lx=length(xarr);
   Uarr=ones(1,lx);
   H0=ArH(6);
   Harr=H0*ones(1,lx);
   H_end=input('give H_end <=4    ');
   Rcred=input('give Rcred');
   Harr(96:146)=H0+(H_end-H0)*(2*xarr(96:146)-1);
   rootRcred=sqrt(Rcred);
   Rt_arr=664*rootRcred*sqrt(xarr);
end  % end choice 7
%  ----------------------------------------------------------------------
last_station=length(xarr);
%--------------------------------------------
if my_choice==6
   xforplot=rootx_plot; % Because of square root behaviour near x=0
else
   xforplot=xarr(1:last_station);
end
% ----------------------------------------------------------------------
flaginstab=zeros(1,fnr);       % We start with stability at all frequencies
Nmax=zeros(1,last_station);     
nfactor=zeros(1,fnr);
dn=zeros(1,fnr);
TU1=zeros(1,fnr);
TU2=zeros(1,fnr);
logHarr=log10(Harr);
Rt_arr(1)=.1*Rt_arr(2);  % to avoid problems with log if Rt-arr(1)=0;
logRt_arr=log10(Rt_arr);
logcrit_arr=ppval(logcrit_vs_logH_spline,logHarr);
logRplot=logRt_arr(1:last_station);
logcritplot=logcrit_arr(1:last_station);
for istat=1:last_station  % To find first unstable point
   if logRt_arr(istat)>=logcrit_arr(istat)
      break
   end
end
iinstab=istat
if iinstab<2
   iinstab=2; %We need a preceding point to integrate
end
% --------------------------------------------------------------------------------------
for istat=iinstab:last_station % ----------------------- start for istat ---------------
   dx=xarr(istat)-xarr(istat-1);% to integrate with trapezoidal rule; we take small steps
   facint=.5*dx*Rcred;
   Rt=Rt_arr(istat);
   H=Harr(istat);
   logRt=log10(Rt);
   rr=logRt-ppval(logcrit_vs_logH_spline,log10(H));
   ome=Finf*Rt/Uarr(istat)^2;
   % ----------------------------------------------------------------------------------
   if version_cross==1 % for extensive cross_cut
   Tss_local=cross_cut(Rt,H);%Find Tss spline at local H and Re-theta  
   dome=(ome-omega_at_axis)/scomega; % all frequencies shifted and scaled
   Tsplined=ppval(Tss_local,dome);
   Tsplined=(Tsplined+TMax)*TMaxMax;% remember that TMax is the value at the axis  
   end
   %  ---------------------------------------------------------------------------------
   if version_cross==2 % for cross_cut_fast
      [aa_left,aa_right]=cross_cut_fast(Rt,H);
      dome=(ome-omega_at_axis)/scomega; % all frequencies shifted and scaled
      kmax=length(dome);
      kk=max(find(dome<0));
      dome_left=dome(1:kk);
      dome_right=dome(kk+1:kmax);
      Tsplined=[aa_left*dome_left.^2    aa_right*dome_right.^2];
      Tsplined=(Tsplined+TMax)*TMaxMax;% remember that TMax is the value at the axis  
   end
   TU1=TU2;
   TU2=Tsplined*Uarr(istat); % to be integrated
   % Note that we do not allow the n-factor to become negative. There will always
   % be neutral disturbancescoming into the boundary layer one way or another.
   % The first amplified and later possibly damped disturbances can not have a 
   % smaller amplitude than the neutral ones.
   % Where the n-factor tends to become <0 it is made =0
   % Depending on the values of "flaginstab" and TU2 (or TU2_f) we have to decide
   % for each frequency how to proceed, based on the table below.
   %|----------------------------------------------------------------------------------
   %| stab_case  |     a          |      b           |      c              |     d      |
   %|----------------------------------------------------------------------------------
   %|flaginstab  |     0          |     0            |      1              |     1      |
   %|----------------------------------------------------------------------------------
   %|TU2 or TU2_f|    <=0         |     >0           |      <=0            |     >0     | 
   %|----------------------------------------------------------------------------------
   %|            | no instability |instability starts|there was instability|unstable    | 
   %|            | up till here   |inside interval   |upstream but         |already and |
   %|            |                |                  |now n starts to      |n increasing|
   %|            |                |                  |decrease             |            |
   %|-----------------------------------------------------------------------------------

   for iom=1:fnr    
       if flaginstab(iom)==0 & TU2(iom)<=0                      % stab_case a
          dn(iom)=0;                        
       elseif flaginstab(iom)==0 & TU2(iom)>0                   % stab_case b 
          dn(iom)=facint*TU2(iom)^2/(TU2(iom)-TU1(iom));
          flaginstab(iom)=1;                             
       else                                                     % stab_case c or d                                           
          dn(iom)=facint*(TU1(iom)+TU2(iom));     
       end
    nfactor(iom)=nfactor(iom)+dn(iom);
       if nfactor(iom)<0
          nfactor(iom)=0;
       end
    end % for iom 
   [Nm,itop]=max(nfactor);
       if Nm==0
          Nmax(istat)=0;
       else
           if itop==fnr
              itop=fnr-1;
           elseif itop==1
              itop=2;
           end
        xinterp=xfr((itop-1):(itop+1));
        yinterp=nfactor((itop-1):(itop+1));
        ppn=polyfit(xinterp,yinterp,2); 
        freqtop=-.5*ppn(2)/ppn(1);
         Nmax(istat)=polyval(ppn,freqtop);
       end
    end % --------------------------------- end for istat  -----------------------
hold off
plot_roadmap 
hold on
xx1=log10(Rt_arr);
yy=logcrit_arr; 
if size(xx1)-size(yy)==0 % to make sure that xx1 and yy are both row or
                         % column vectors before subtracting them
   xx=log10(Rt_arr)-yy;
else
   xx=log10(Rt_arr)-yy';
end
plot(xx,yy,'g',xx,yy,'x g');
grid on
shg
disp ('Command is returned to keyboard')
disp ('to view and/or print this figure')
disp ('Resume execution by typing "return" at the K-prompt')
keyboard
hold off
plot(xforplot,Nmax)
grid on
hold on
plot(xforplot,logRplot,'k',xforplot,logcritplot,'k--')
legend('N','log-Re-theta','log-Re-theta-crit',0)
switch my_choice
   case 1
        title('PhD case van Ingen')
   case 2
        title('Flat plate; Rc-red=10')
   case 3 
        title('Flat plate with oscillating H superimposed ')
   case 4 
        title('Flat plate with reduced H-region ')
   case 5
        title('Rheinboldt 1.0  ')
   case 6 
        title('Iglisch flow')
   case 7 
        title('Simulated rooftop airfoil   ')
 end % switch
   
 if my_choice==6
    xlabel('sqrt(x/c')
 else
    xlabel ('x/c')
 end
shg 
disp ('Command is returned to keyboard')
disp ('to view and/or print this figure')
disp ('Resume execution by typing "return" at the K-prompt')
keyboard
hold off
plot(xforplot,Harr,'k')
grid on
legend ('H',0)
switch  my_choice
   case 1
        title('H for PhD case van Ingen')
   case 2
        title('H for flat plate')
   case 3 
        title('H for flat plate with oscillating H superimposed')
   case 4 
        title('H for flat plate with reduced H-region')
   case 5 
        title('H for Rheinboldt 1.0  ')
   case 6 
        title('H for Iglisch flow')
   case 7 
        title('H for simulated rooftop airfoil')
 end % switch
 if my_choice==6
    xlabel('sqrt(x/c')
 else
    xlabel ('x/c')
 end
 shg
 disp ('Command is returned to keyboard')
 disp ('to view and/or print this figure')
 disp ('Resume execution by typing "return" at the K-prompt')
 keyboard
 close all
 



   
   
 