
% Amplification.m  (CD-ROM version)
% To calculate the N_factor for a given distribution of  x,U,H and R-theta.
% In this program we just calculate the N-factor. You may later introduce an "effective 
% turbulence level" Tu to define the critical N-factor (Ncrit) to stop the calculation and
% switch to turbulent flow.
% In that case you may want to do the N-factor calculation step by step together with the
% laminar boundary layer calculation; it should not be difficult to adjust the program to
% your needs.
% We have predefined some typical cases; you can easily add your own case.
% Here we assume the laminar boundary layer to be known from a preceding calculation.
% After having built up experience with this program you may want to reduce the
% range of frequencies, and/or the number of frequencies within that range, to be used. 
% At present this range is rather wide to accommodate applications in the upper right-hand
% corner of the roadmap area. Please observe the used frequencies in the detailed plots 
% (figures 2 and 3). 
% As soon as edge maxima for the n-factor as function of frequency occur you need to
% adjust the frequency range.
% We will denote the amplification factor as function of the frequency by n.
% We will denote the maximum amplification factor as function of x by N.
% For further explanations see chapter 12 of the report.
% Practical applications inserted into XFOIL can be found in the Masters thesis of 
% J. Bongers (see report on the CD-ROM) 
% No attempt has been made to optimise the MATLAB program. For routine (design) 
% applications you may use an optimising (e.g. C-) compiler to speed up the computation. 
% Also the "accelerator" for loops in later versions of MATLAB may be useful.
% The present version of the program allows you to use either:
%             1)  cross_cut
%             2)  cross_cut_fast
%             3)  both versions in parallel
% At each x-station detailed plots of T*U vs frequency and n-factor vs frequency are 
% provided on request.Also the trace of the boundary layer in a "roadmap" and the growth 
% of N with x may be followed.
% A companion program "ampli" lets you run either cross_cut or cross_cut_fast without 
% the detailed plots.
% --------------------------------------------------------------------------------------
clear
close all
global ...
ArMaxMaxT ArlogRtcrit r_grid Tbar Tss  domega_saved logFax ... 
logMaxMaxT_vs_logcrit_spline logcrit_vs_logH_spline rtop_vs_logcrit_spline ... 
scale_domega_vs_logcrit_spline  slope_left_vs_logcrit_spline ...
ArNumberofReynolds ArH Arscomega Arr omega_Arnal T_Arnal ome_ax fnr ri ...
logcriti log_Ftop_spline TMax TMaxMax omega_at_axis scomega  coefs_log_Ftop ...
coefs_log_MaxMaxT   coefs_scale coefs_rtop  coefs_slope_left ...
coefs_logcrit_vs_logH  pp_overall_left  pp_overall_right    
% The global statement above may contain more variables than really needed because
% we kept the global statement the same for a number of m-files. 
% ----------------------------------  end global  ------------------------------------
load datafile_for_n_factor
% ------------------------------------------------------------------------------------
disp ('You may use various versions of "cross_cut"                ')
disp ('1=The extensive one (cross_cut)                            ')
disp ('2=The fast approximate one (cross_cut_fast)                ')
disp ('3=Both at the same time to be able to compare the results  ')
version_cross=input('give your choice:  1, 2 or 3                  ')
close all
freqs=[-7 -1  601];% This is a rather wide range of frequencies. For practical
% applications you may want to reduce this range and/or the number of frequencies
% within that range after having built up experience with the method.
% Just keep an eye on the detailed plots.  
f1=freqs(1);
f2=freqs(2);
fnr=freqs(3);
Finf=logspace(f1,f2,fnr);
xfr=[1:fnr];
% The N-factor calculations should be done for constant values of omega, 
% that is constant Finf=omega*nu/Uinf^2. Other researchers have used for convenience 
% constant F=omega*nu/U^2
% Our experience has shown that the final results show negligible differences
% because we use the envelope for a large number of frequencies.
% We will always use the first option.
% -------------------------------------------------------------------------------------
disp('------------------------------------------------ ----')
disp('       You have a choice from various cases          ')
disp('       1=PhD case van Ingen                          ')
disp('       2=flat plate                                  ')
disp('       3=flat plate with oscillating H superimposed  ')
disp('       4=flat plate with reduced H-region            ')
disp('       5=Rheinboldt 1.0                              ')
disp('       6=Iglisch                                     ')
disp('       7=simulated rooftop airfoil                   ')
disp('       8=you may add your own cases here             ')
disp('-----------------------------------------------------')
my_choice=input('give the number of your choice;   1<= number <=7   ');
% ------------------------------------------------------------------------------------
% Call here the m-file to prepare x,U,H,R-theta 
% Use arrays xarr,Uarr,Harr and Rt_arr respectively
% Also give the chord Reynolds number as Rcred,that is leave out a factor 1E6 
% -------------------------------- choice=1 ------------------------------------------
if my_choice==1
   load results_PhD_case % for explanation see chapter 12 of report
   xarr=xtemp(1:stop_station);
   Rt_arr=Rtetatemp(1:stop_station);
   Harr=bightemp(1:stop_station);
   Uarr=Utemp(1:stop_station);
   Rcred=Rc*1E-6;
end % end choice 1
%  -----------------------------  choice=2  ----------------------------------------
if my_choice==2
   xarr=[0:.001:.05  .06:.01:1 ] ;% We take small steps near x=0 so that we can
   lx=length(xarr);               % safely take Re_theta(1)=.1*Re_theta(2) to avoid
   Uarr=ones(1,lx);               % problems with Log if Re_theta(1)=0
   Harr=2.591*ones(1,lx); 
   Rcred=10;
   rootRcred=sqrt(Rcred);
   Rt_arr=664*rootRcred*sqrt(xarr);
end % end choice 2
%  ----------------------------  choice==3  --------------------------------------- 
if my_choice==3
   % we put a sinusoidal oscillation on H for the flat plate to see the effect on 
   % the n-factor. Just to keep it simple Re-theta is taken equal to the standard
   % flat plate case with H=constant=2.591
   % Note that in many cases the effect of pressure gradient and/or suction 
   % on the n-factor is mostly through H and not through Re-theta 
   xarr=[0:.001:.05  .06:.01:1 ] ;% Same as for choice 2
   lx=length(xarr);
   Uarr=ones(1,lx);
   H0=2.591
   dH=input('give dH, may be >= or < 0 a good choice is +.2 or -.2       ')
   Harr=H0*ones(1,lx);
   Rcred=10;
   rootRcred=sqrt(Rcred);
   Rt_arr=664*rootRcred*sqrt(xarr);
   station1=96; station2=lx;
   x1=xarr(station1);
   x2=xarr(station2);
   d=2*pi/(x2-x1);
   Harr(station1:station2)=H0+dH*sin(d*(xarr(station1:station2)-x1));
end % end choice 3
% ----------------------------------   choice=4   -------------------------------
if my_choice==4
   % we put a low H-region between x/c=.2 and .5;just to keep it simple R-theta is 
   % taken equal to that for H=constant as in choice 5
   xarr=[0:.001:.05  .06:.01:1 ] ;% Same as for choice 2 and 3
   lx=length(xarr);
   Uarr=ones(1,lx);
   H0=2.591
   Harr=H0*ones(1,lx);
   Rcred=10; 
   rootRcred=sqrt(Rcred);
   Rt_arr=664*rootRcred*sqrt(xarr);
   station1=66; station2=96;
   x1=xarr(station1);
   x2=xarr(station2);
   dH=input('give dH=dip in H; .3 is a good example');
   temp=dH/.15^2;
   Harr(station1:station2)=H0-dH+temp*(xarr(station1:station2)-xarr(81)).^2;
end  % end choice 4
% ---------------------------------- choice=5  ----------------------------
if my_choice==5
   load results_Rheinb   % for explanation see chapter 12 of the report
   xarr=x;
   Harr=bigh;
   Rt_arr=Rteta;
   Uarr=U;
end  % end choice 5
% -------------------------------------choice=6 ---------------------------------------
if my_choice==6
   load results_Iglisch_501_10  
                             % Results from a finite difference boundary layer
                             % calculation with 501 points across the boundary layer
                             % and 10 iterations per x-step
                             % Contains rootx from 0 to 3, teta,tau,bigh,Iglischtable
                             % rootx_plot (127 values from 0 to 1), H_plot and theta_plot,
                             % also an array with earlier calculated N-values to be used 
                             % in a separate program (see report)                   
                             % note that xarr = cq^2 * U*x/nu and because cq is of the 
                             % order 1E-4 Reynolds-x is very soon of the order 1E8. 
   xarr=rootx_plot.^2;
   xforplot=rootx_plot;
   Harr=H_plot;
   last_station=length(xarr);    % =127
   Uarr=ones(1,last_station);
   % ------------------------------------------------------------------------------------
   disp('you will be asked to input cqred=cq*1E4                                     ')
   disp('good examples are .5 and 1.5                                                ')
   disp('For .5 the N-factor will exceed 10; for 1.5 there will be complete stability')
   cqred=input('give cq*1E4       ')
   cq=.0001*cqred;
   Rc=cq^-2;
   Rt_arr=theta_plot.*rootx_plot/cq;
   Rcred=Rc*1E-6;
end % end choice 6 (Iglisch)
% --------------------------------------choice=7 ------------------------------------
if my_choice==7
   % We take a flat plate for 0<=x<=.5 and let H linearly increase from the 
   % flat plate value at x=.5 to H_end at x=1
   % Just to keep it simple Re-theta is taken equal to that for the flat plate
   % as in previous examples
   xarr=[0:.001:.05  .06:.01:1 ]; 
   lx=length(xarr);
   Uarr=ones(1,lx);
   H0=ArH(6);
   Harr=H0*ones(1,lx);
   H_end=input('give H_end <=4    ');
   Rcred=input('give Rcred');
   Harr(96:146)=H0+(H_end-H0)*(2*xarr(96:146)-1);
   rootRcred=sqrt(Rcred);
   Rt_arr=664*rootRcred*sqrt(xarr);
end  % end choice 7
%------------------------------------------------------------------------------
pausetime=input('To view results for n sec. at each x give n>0 else n=0  ');
if pausetime>0
   disp ('Note that figs 2 and 3 are not updated at x-stations where N=0 ')
   subplot(2,2,1)     %-------------------------------------------------Fig 1 on 
   hold off                                                                     
   plot_roadmap 
   hold on 
   disp('In addition to a pause for n seconds you may request the opportunity  ')
   disp('to print the detailed plots for the current x-station                 ')
   opportunity_to_print=input ('If yes give 1 else give 0       ')
end
% ------------------------------------------------------------------------------
last_station=length(xarr);
%--------------------------------------------
if my_choice==6
   xforplot=rootx_plot; % Because of square root behaviour near x=0
else
   xforplot=xarr(1:last_station);
end
% --------------------------------------------------------------------------------
if version_cross==1 | version_cross==3 % prepare for extensive cross_cut
   flaginstab=zeros(1,fnr);            % We start with stability at all frequencies
   Nmax=zeros(1,last_station);     
   nfactor=zeros(1,fnr);
   dn=zeros(1,fnr);
   TU1=zeros(1,fnr);
   TU2=zeros(1,fnr);
end
% ---------------------------------------------------------------------------------
if version_cross==2 | version_cross==3 % prepare for cross_cut_fast
   flaginstab_f=zeros(1,fnr);          % We start with stability at all frequencies
   Nmax_f=zeros(1,last_station);       % with _f we denote the fast version
   nfactor_f=zeros(1,fnr);
   dn_f=zeros(1,fnr);
   TU1_f=zeros(1,fnr);
   TU2_f=zeros(1,fnr);
end
% -------------------------------------------------------------------------------
logHarr=log10(Harr);
Rt_arr(1)=.1*Rt_arr(2);  % to avoid problems with log if Rt-arr(1)=0;
logRt_arr=log10(Rt_arr);
logcrit_arr=ppval(logcrit_vs_logH_spline,logHarr);
logRplot=logRt_arr(1:last_station);
logcritplot=logcrit_arr(1:last_station);
if pausetime > 0
   subplot(2,2,4)    % ------------------------------------------------- Fig 4 on
   hold off
   plot(xforplot,logRplot,'k',xforplot,logcritplot,'-- k')
   grid on
   hold on
   xlabel( 'x/c')
   ylabel ('N:(+)for extensive;(x)for fast.   LogRt(full curve),LogRtcrit(-----)')
   title('10Log(Re-theta) 10Log(Re-theta-crit and N-factor')
end
for istat=1:last_station  % To find first unstable point
   if logRt_arr(istat)>=logcrit_arr(istat)
      break
   end
end
iinstab=istat
if iinstab<2
   iinstab=2; %We need a preceding point to integrate
end
% -------------------------------------------------------- begin for istat -------
for istat=iinstab:last_station 
   dx=xarr(istat)-xarr(istat-1);%to integrate with trapezoidal rule take small steps
   facint=.5*dx*Rcred;
   Rt=Rt_arr(istat);
   H=Harr(istat);
   logRt=log10(Rt);
   rr=logRt-ppval(logcrit_vs_logH_spline,log10(H));
   ome=Finf*Rt/Uarr(istat)^2;
   % ----------------------------------------------------------------------------------
   if version_cross==1|version_cross==3         % For extensive cross_cut
      Tss_local=cross_cut(Rt,H);                % Find Tss spline at local H and Re-theta  
      dome=(ome-omega_at_axis)/scomega;         % All frequencies shifted and scaled
      Tsplined=ppval(Tss_local,dome);
      Tsplined=(Tsplined+TMax)*TMaxMax;      % remember that TMax is the value at the axis  
   end
   %  ---------------------------------------------------------------------------------
   if version_cross==2 | version_cross==3  % for cross_cut_fast
      [aa_left,aa_right]=cross_cut_fast(Rt,H);
      dome=(ome-omega_at_axis)/scomega; % all frequencies shifted and scaled
      kmax=length(dome);
      kk=max(find(dome<0));
      dome_left=dome(1:kk);
      dome_right=dome(kk+1:kmax);
      Tsplined_f=[aa_left*dome_left.^2    aa_right*dome_right.^2];
      Tsplined_f=(Tsplined_f+TMax)*TMaxMax;% remember that TMax is the value at the axis  
   end
   if pausetime > 0
      subplot(2,2,1)     % ----------------------------------------------Fig 1 on
      hold on
      plot(ri,logcriti,'x g');% plot green x in roadmap
   end
   if version_cross==1|version_cross==3    % for extensive cross_cut
      TU1=TU2;
      TU2=Tsplined*Uarr(istat);            % to be integrated
   end
   if version_cross==2 | version_cross==3  % for cross_cut_fast
      TU1_f=TU2_f;
      TU2_f=Tsplined_f*Uarr(istat);        % to be integrated
   end
   % Note that we do not allow the n-factor to become negative. There will always
   % be neutral disturbancescoming into the boundary layer one way or another.
   % The first amplified and later possibly damped disturbances can not have a 
   % smaller amplitude than the neutral ones.
   % Where the n-factor tends to become <0 it is made =0
   % Depending on the values of "flaginstab" and TU2 (or TU2_f) we have to decide
   % for each frequency how to proceed, based on the table below.
   %|----------------------------------------------------------------------------------
   %| stab_case  |     a          |      b           |      c              |     d      |
   %|----------------------------------------------------------------------------------
   %|flaginstab  |     0          |     0            |      1              |     1      |
   %|----------------------------------------------------------------------------------
   %|TU2 or TU2_f|    <=0         |     >0           |      <=0            |     >0     | 
   %|----------------------------------------------------------------------------------
   %|            | no instability |instability starts|there was instability|unstable    | 
   %|            | up till here   |inside interval   |upstream but         |already and |
   %|            |                |                  |now n starts to      |n increasing|
   %|            |                |                  |decrease             |            |
   %|-----------------------------------------------------------------------------------

   if version_cross==1|version_cross==3  % for extensive cross_cut
      for iom=1:fnr    
         if flaginstab(iom)==0 & TU2(iom)<=0                         % stab_case a
            dn(iom)=0;                        
         elseif flaginstab(iom)==0 & TU2(iom)>0                      % stab_case b 
            dn(iom)=facint*TU2(iom)^2/(TU2(iom)-TU1(iom));
           flaginstab(iom)=1;                             
         else                                                        % stab_case c or d                                           
           dn(iom)=facint*(TU1(iom)+TU2(iom));     
         end
         nfactor(iom)=nfactor(iom)+dn(iom);
         if nfactor(iom)<0
            nfactor(iom)=0;
         end
      end % for iom 
   end
   if version_cross==2 | version_cross==3   % for cross_cut_fast
      for iom=1:fnr    
          if flaginstab_f(iom)==0 & TU2_f(iom)<=0                     % stab_case a
             dn_f(iom)=0;                        
          elseif flaginstab_f(iom)==0 & TU2_f(iom)>0                  % stab_case b
             dn_f(iom)=facint*TU2_f(iom)^2/(TU2_f(iom)-TU1_f(iom));
             flaginstab_f(iom)=1;                             
          else                                                
             dn_f(iom)=facint*(TU1_f(iom)+TU2_f(iom));                % stab_case c or d   
          end
          nfactor_f(iom)=nfactor_f(iom)+dn_f(iom);
          if nfactor_f(iom)<0
             nfactor_f(iom)=0;
          end
      end % for iom  
   end
   if version_cross==1 | version_cross==3 % extensive version
      [Nm,itop]=max(nfactor);
      if Nm==0
         Nmax(istat)=0;
         plot_extensive=0;
         freqtop=itop;
      elseif itop==1 | itop==fnr
         disp ('edge maximum !!!!')
         Nmax(istat)=nfactor(itop);
         plot_extensive=1;
         freqtop=itop;
      else
         xinterp=xfr((itop-1):(itop+1));
         yinterp=nfactor((itop-1):(itop+1));
         ppn=polyfit(xinterp,yinterp,2); 
         freqtop=-.5*ppn(2)/ppn(1);
         Nmax(istat)=polyval(ppn,freqtop);
         plot_extensive=1;
      end
      if Nmax(istat)>0
         fnrplot=find(nfactor>0);
         nfactor_plot=nfactor(fnrplot);
         TU2plot=TU2(fnrplot);
      end
   end
   if version_cross==2 | version_cross==3  % fast version
      [Nm,itop]=max(nfactor_f);
      if Nm==0
         Nmax_f(istat)=0;
         plot_fast=0;
         freqtop_f=itop;
      elseif itop==1 | itop==fnr
         disp ('edge maximum !!!!')
         Nmax_f(istat)=nfactor_f(itop);
         plot_fast=1;
         freqtop_f=itop;
      else
         xinterp=xfr((itop-1):(itop+1));
         yinterp=nfactor_f((itop-1):(itop+1));
         ppn=polyfit(xinterp,yinterp,2); 
         freqtop_f=-.5*ppn(2)/ppn(1);
         Nmax_f(istat)=polyval(ppn,freqtop_f);
         plot_fast=1;
      end
      if Nmax_f(istat)>0
       fnrplot_f=find(nfactor_f>0);
       nfactor_plot_f=nfactor_f(fnrplot_f);
       TU2plot_f=TU2_f(fnrplot_f);
      end
   end
   if pausetime > 0  % plot details and pause to review --------------------------
            switch version_cross
            case 1  % only extensive version 
                    subplot(2,2,4)   %  ---------------------------------  Fig. 4 on
                    hold on
                    plot(xforplot(istat),Nmax(istat),'+')  
                 if plot_extensive==1
                    subplot(2,2,2)     % -------------------------------  Fig. 2 on
                    hold off
                    plot(fnrplot,TU2plot,fnrplot,TU2plot,'+')
                    %hold on
                    grid on
                    title('TU2 vs freq. nr for x-station; extensive version')
                    subplot(2,2,3)      %  ------------------------------- Fig.3 on
                    hold off
                    plot(fnrplot,nfactor_plot,fnrplot,nfactor_plot,'+')% n vs number
                    grid on
                    %hold on
                    title('n vs freq. nr for x-station; extensive version')
                  end
             case 2 % only fast version
                    subplot(2,2,4)   %  ---------------------------------  Fig. 4 on
                    hold on
                    plot(xforplot(istat),Nmax_f(istat),'x')  
                  if plot_fast==1
                    subplot(2,2,2)     % --------------------------------  Fig. 2 on
                    hold off   
                    plot(fnrplot_f,TU2plot_f,fnrplot_f,TU2plot_f, 'x')
                    grid on
                    title('TU2-f vs freq. nr for x-station; fast')
                    subplot(2,2,3)      %  ------------------------------- Fig.3 on
                    hold off
                    plot(fnrplot_f,nfactor_plot_f,fnrplot_f,nfactor_plot_f,'x')%n vs nr
                    grid on
                    %hold on
                    title('n vs freq. nr for x-station;fast')
                  end
               case 3  % both versions parallel
                    subplot(2,2,4)   %  ---------------------------------------Fig. 4 on
                    hold on
                    plot(xforplot(istat),Nmax(istat),'+')      
                    hold on
                    plot(xforplot(istat),Nmax_f(istat),'x')   
                 if plot_extensive==1 & plot_fast==1
                    subplot(2,2,2)     % ---------------------------------  Fig. 2 on
                    hold off
                    plot(fnrplot,TU2plot,fnrplot,TU2plot,'+')
                    grid on
                    hold on
                    plot(fnrplot_f,TU2plot_f,fnrplot_f,TU2plot_f, 'x')
                    title('TU2 vs freq. nr for x-station; (+)=extensive ; (x)=fast')
                    subplot(2,2,3)      %  --------------------------------- Fig.3 on
                    hold off
                    plot(fnrplot,nfactor_plot,fnrplot,nfactor_plot,'+')% n vs nr
                    grid on
                    hold on
                    plot(fnrplot_f,nfactor_plot_f,fnrplot_f,nfactor_plot_f,'x')% n vs nr
                    title('n vs freq. nr for x-station; (+)=extensive;(x)=fast')
                 end
              end   % end switch
   shg           
   if opportunity_to_print==0           
      pause(pausetime)
   else
      disp ('You may return to keyboard to print these 4 figures on one page')
      iprint=input('If yes give 1 else give 0         ')
      if iprint==1
        keyboard
      end
   end
  end % --------------------------------  end if pausetime > 0 ------------------ 
end % for istat % ------------------------end for istat        ------------------
close all
plot_roadmap 
xx1=log10(Rt_arr);
yy=logcrit_arr; 
if size(xx1)-size(yy)==0 % to make sure that xx1 and yy are both row or
                         % column vectors before subtracting them
   xx=log10(Rt_arr)-yy;
else
   xx=log10(Rt_arr)-yy';
end
plot(xx,yy,'g',xx,yy,'x g');
grid on
shg
disp ('You may return to keyboard to print this figure')
iprint=input('If yes give 1 else give 0               ')
     if iprint==1
        keyboard
     end
hold off
if version_cross==1 % for extensive cross_cut 
   plot(xforplot,Nmax,'k',xforplot,Nmax,'k+')
   hold on
   plot(xforplot,logRplot,'k',xforplot,logcritplot,'k--')
   grid on
   legend('N-ext','N-ext','log-Re-theta','log-Re-theta-crit',0)
end
if version_cross==2 % for cross_cut_fast
   plot(xforplot,Nmax_f,'k',xforplot,Nmax_f,'kx')
   hold on
   plot(xforplot,logRplot,'k',xforplot,logcritplot,'k--')
   grid on
   legend('N-fast','N-fast','log-Re-theta','log-Re-theta-crit',0)
end
if version_cross==3  % both versions of cross_cut
   plot(xforplot,Nmax,'k',xforplot,Nmax_f,'k',xforplot,Nmax,'k+',xforplot,Nmax_f,'kx')     
   hold on
   plot(xforplot,logRplot,'k',xforplot,logcritplot,'k--')
   grid on
   legend('N-ext','N-fast','N-ext','N-fast','log-Re-theta','log-Re-theta-crit',0)
end
switch my_choice
      case 1
      title('PhD case van Ingen')
      case 2
      title('Flat plate; Rc-red=10')
      case 3 
      title('Flat plate with oscillating H superimposed ')
      case 4 
      title('Flat plate with reduced H-region ')
      case 5
      title('Rheinboldt 1.0  ')
      case 6 
      title('Iglisch flow')
      case 7 
      title('Simulated rooftop airfoil   ')
 end % switch
 if my_choice==6
    xlabel('sqrt(x/c')
 else
    xlabel ('x/c')
 end
 shg
 disp ('You may return to keyboard to print this figure')
iprint=input('If yes give 1 else give 0               ')
     if iprint==1
        keyboard
     end
hold off
legend off
plot(xforplot,Harr,'k')
grid on
switch  my_choice
   case 1
      title('H for PhD case van Ingen')
   case 2
      title('H for flat plate')
   case 3 
      title('H for flat plate with oscillating H superimposed')
   case 4 
      title('H for flat plate with reduced H-region')
   case 5 
      title('H for Rheinboldt 1.0  ')
   case 6 
      title('H for Iglisch flow')
   case 7 
      title('H for simulated rooftop airfoil')
end % switch
if my_choice==6
   xlabel('sqrt(x/c')
else
   xlabel ('x/c')
end
shg
disp ('You may return to keyboard to print this last figure')
iprint=input('If yes give 1 else give 0                    ')
     if iprint==1
        keyboard
     end
 close all
 

   
   
 