% Hartree_zpg_pg.m   CD-ROM version
% M-file to find `the values of "el", mT and H for
% a Hartree profile with pressure gradient (but without suction/blowing)
% with the same vale of "el", mT or H as for the flat plate with
% suction/ blowing.
% The results of this program give support to some conclusions made in
% chapter 4 of the report.
% ----------------------------------------------------------------------
% We will be using two datafiles namely Hartreetablezpg and Hartree_pg
% ----------------------------------------------------------------------
% Hartreetablezpg contains the following results for the flat plate with 
% suction/ blowing. See chapter 4 of the report
% The array "results" is the same as table 4.1
% ---------------------------------------------------
% Name              Size          Bytes    Class
% ---------------------------------------------------
% arbighzpg         1x23           184  double array
% ardstarzpg        1x23           184  double array
% arelzpg           1x23           184  double array
% aretamaxzpg       1x23           184  double array
% arf0zpg           1x23           184  double array
% arfpp0zpg         1x23           184  double array
% armTzpg           1x23           184  double array
% arthetazpg        1x23           184  double array
% results           23x6          1104  double array
% ----------------------------------------------------------------------

% Hartree_pg contains the valuea of beta and f''(0) for the comparison
% profiles for equal "el", mT or H, that is for npar=1, 2 or 3
% ----------------------------------------------------------------------
%  Name         Size          Bytes  Class
% -------------------------------------------------
% fsk_beta      23x3            552  double array
% fsk_fpp0      23x3            552  double array
% -------------------------------------------------
%  fsk_beta =beta for 
%   npar=1    npar=2     npar=3
% ------------------------------
%     (99)      (99)   (10.1853)
%   (1.3965)    (99)    (1.1469)
%   (1.2187)    (99)    (1.0238)
%   (1.0612)    (99)    (0.9109)
%   (0.9222)    (99)    (0.8074)
%    0.7987    1.1418    0.7119
%    0.6886    0.9363    0.6240
%    0.5900    0.7676    0.5429
%    0.5013    0.6270    0.4679
%    0.4213    0.5085    0.3985
%    0.3490    0.4076    0.3343
%    0.2836    0.3211    0.2747
%    0.2242    0.2466    0.2196
%    0.1703    0.1821    0.1685
%    0.1213    0.1262    0.1212
%    0.0768    0.0778    0.0775
%    0.0365    0.0360    0.0372
%    0.0000    0.0000    0.0000
%   -0.0625   -0.0562   -0.0651
%   -0.1124   -0.0935   -0.1185
%   -0.1506   -0.1124   -0.1600
%   -0.1776   -0.1103   -0.1883
%  (-0.1935) (-0.0800)  (-0.1987)

% --------------------------------
%  fsk_fpp0 = f"(0) for 
%     npar=1   npar=2     npar=3
% --------------------------------
%     (99)      (99)      (99)
%   (1.8211)    (99)    (1.4173)
%   (1.5215)    (99)    (1.2604)
%   (1.3057)    (99)    (1.1344)
%   (1.1463)    (99)    (1.0298)
%    1.0214    1.4104    0.9403
%    0.9193    1.1615    0.8623
%    0.8331    0.9918    0.7932
%    0.7585    0.8650    0.7310
%    0.6928    0.7645    0.6742
%    0.6341    0.6817    0.6221
%    0.5808    0.6114    0.5736
%    0.5320    0.5505    0.5281
%    0.4868    0.4968    0.4853
%    0.4446    0.4490    0.4446
%    0.4050    0.4059    0.4056
%    0.3676    0.3671    0.3682
%    0.3321    0.3321    0.3320 % this is the flat plate
%    0.2655    0.2726    0.2626
%    0.2040    0.2285    0.1956
%    0.1466    0.2040    0.1297
%    0.0931    0.2068    0.0635
%    0.0443    0.2451   -0.0053
% --------------------------------
% Note that entries between ( ) in these tables should 
% not be used because these have either not been calculated (99)
% or are not accurate enough (x.xxxxx).
% In both cases this is due to the fact that for the given values
% of el, mT or H there is no Hartree profile for -.19883.. <=beta<= 1
% Although Hartree profiles without suction do exist for beta>1 we did 
% not calculate them because we used a procedure that had been 
% specially developed for beta not much >1
% Note that for nr=18 (flat plate without suction/blowing)the actual
% and comparison profile are identical
clear
close all
load Hartreetablezpg
load Hartree_pg
fwall=0;
bign=501;
xplot=results(:,1);
% ---------------------------------------
figure (1)    % open figure 1 to plot el
hold off
plot(xplot(6:23),results(6:23,4),'--')
grid on
hold on
% ---------------------------------------
figure (2)    % open figure 2 to plot mT
hold off
plot(xplot(6:23),results(6:23,5),'--')
grid on
hold on
% ---------------------------------------
figure (3)    % open figure 3 to plot H
hold off
plot(xplot(6:23),results(6:23,6),'--')
grid on
hold on
% ---------------------------------------
for npar=1:3 
   for nr=6:23
   betaa=fsk_beta(nr,npar);
   etamax=results(nr,3);
   fpp0=fsk_fpp0(nr,npar);
   [H,el,mT,u,shear,curve,y_bar]=find_Hartree(betaa,etamax,bign,fwall,fpp0);
   figure (1)
   if npar==1
      plot(xplot(nr),el,'+')
   elseif npar==2
      plot(xplot(nr),el,'x')
   else
      plot(xplot(nr),el,'o')
   end
   % ----------------------------
   figure (2)      
   if npar==1
      plot(xplot(nr),mT,'+')
   elseif npar==2
      plot(xplot(nr),mT,'x')
   else
      plot(xplot(nr),mT,'o')
   end
   % ---------------------------
   figure (3)      
   if npar==1
      plot(xplot(nr),H,'+')
   elseif npar==2
      plot(xplot(nr),H,'x')
   else
      plot(xplot(nr),H,'o')
   end
   % ---------------------------
end
end
figure (1)
   xlabel('f(0) for flat plate')
   ylabel('el')
   title('Values of "el" for actual(--) and comp.profiles at equal el(+),mT(x)or H(o)')
   shg
   disp('view and/or print figure 1')
   disp('type "return" to go to fig. 2 ')
   keyboard
   % ----------------------------------------------------------------------------------
   figure (2)
   xlabel('f(0) for flat plate')
   ylabel('mT')
   title('Values of mT for actual(--) and comp. profiles at equal el(+),mT(x)or H(o)')
   shg
   disp('view and/or print figure 2')
   disp('type "return" to go to fig. 3 ')
   keyboard
% ----------------------------------------------------------------------------------
   figure (3)
   xlabel('f(0) for flat plate')
   ylabel('H')
   title('Values of H for actual(--)and comparison profiles at equal el(+),mT(x) or H(o)')
   shg
   disp('view and/or print figure 3')
   disp('type "return" to proceed ')
   keyboard
% ------------------------------------------------------------------------------------   
disp ('Please note that the choice for equal H seems to be the best,         ')
disp ('The choice for equal mT, that is equal profile curvature at the wall, ')
disp ('does not bring much                                                   ')
disp ('Below we will repeat the preceding program for npar=3 only to show the')
disp ('results for equal H only                                              ')
disp ('To resume execution of the program type "return"                      ')
keyboard
close all  
% ---------------------------------------
figure (1)    % open figure 1 to plot el
hold off
plot(xplot(6:23),results(6:23,4),'--')
grid on
hold on
% ---------------------------------------
figure (2)    % open figure 2 to plot mT
hold off
plot(xplot(6:23),results(6:23,5),'--')
grid on
hold on
% ---------------------------------------
figure (3)    % open figure 3 to plot H
hold off
plot(xplot(6:23),results(6:23,6),'--')
grid on
hold on
% ---------------------------------------
for npar=3 
   for nr=6:23
   betaa=fsk_beta(nr,npar);
   etamax=results(nr,3);
   fpp0=fsk_fpp0(nr,npar);
   [H,el,mT,u,shear,curve,y_bar]=find_Hartree(betaa,etamax,bign,fwall,fpp0);
   % -----------------------------------------------------------------------
   figure (1)
   plot(xplot(nr),el,'o')
   % ----------------------------
   figure (2)      
   plot(xplot(nr),mT,'o')
   % ---------------------------
   figure (3)      
   plot(xplot(nr),H,'o')
   % ---------------------------
   end
end
   figure (1)
   xlabel('f(0) for flat plate')
   ylabel('el')
   title('Values of "el" for actual(--) and comparison profiles at equal H(o)')
   shg
   disp('view and/or print figure 1')
   disp('type "return" to go to fig. 2 ')
   keyboard
% ---------------------------------------------------------------------------
   figure (2)
   xlabel('f(0) for flat plate')
   ylabel('mT')
   title('Values of mT for actual(--) and comparison profiles at equal H(o)')
   shg
   disp('view and/or print figure 2')
   disp('type "return" to go to fig. 3 ')
   keyboard
% ---------------------------------------------------------------------------
   figure (3)
   xlabel('f(0) for flat plate')
   ylabel('H')
   title('Values of H for actual (--) and comparison profiles at equal H(o)')
   shg
   disp('view and/or print figure 3')
   disp('type "return" to proceed ')
   keyboard
% ---------------------------------------------------------------------------   
close all
 
  
