% comp_Hartree_suc_nosuc   CD-ROM version
% We have earlier calculated 23 Hartree velocity profiles for 
% a flat plate with various amounts of suction and blowing.
% Results are in "results" in "Hartreetablezpg" as shown below.
%           1         2         3         4        5          6
% nrprof   f(0)     f''(0)    eta_max     el       mT         H
%  1     10.0000    5.0485    5.0000    0.4894   -0.2372    2.0153
%  2      1.6000    0.9897    8.0000    0.3755   -0.1140    2.2024
%  3      1.5000    0.9454    8.0000    0.3695   -0.1083    2.2138
%  4      1.4000    0.9014    8.0000    0.3632   -0.1024    2.2261
%  5      1.3000    0.8578    8.0000    0.3564   -0.0963    2.2394
%  6      1.2000    0.8144    8.0000    0.3493   -0.0899    2.2539
%  7      1.1000    0.7715    8.0000    0.3417   -0.0832    2.2696
%  8      1.0000    0.7289    8.0000    0.3336   -0.0764    2.2866
%  9      0.9000    0.6867    8.0000    0.3251   -0.0692    2.3053
% 10      0.8000    0.6450    8.0000    0.3160   -0.0619    2.3257
% 11      0.7000    0.6037    8.0000    0.3064   -0.0544    2.3481
% 12      0.6000    0.5630    8.0000    0.2961   -0.0467    2.3727
% 13      0.5000    0.5228    8.0000    0.2853   -0.0389    2.3999
% 14      0.4000    0.4833   10.0000    0.2738   -0.0310    2.4300
% 15      0.3000    0.4443   10.0000    0.2616   -0.0231    2.4636
% 16      0.2000    0.4061   12.0000    0.2486   -0.0152    2.5011
% 17      0.1000    0.3687   12.0000    0.2350   -0.0075    2.5433
% 18           0    0.3321   12.0000    0.2205         0    2.5911
% 19     -0.2000    0.2616   12.0000    0.1892    0.0137    2.7080
% 20     -0.4000    0.1956   12.0000    0.1547    0.0245    2.8658
% 21     -0.6000    0.1349   12.0000    0.1173    0.0306    3.0909
% 22     -0.8000    0.0808   14.0000    0.0777    0.0299    3.4419
% 23     -1.0000    0.0355   16.0000    0.0380    0.0204    4.0995   


%-------------------------------------------------------------------------------
% Note that number 1 is for very strong suction; this boundary layer 
% approaches the asymptotic suction profile (H=2);
% Nr 18 is the flat plate without suction/blowing. Hence actual and comparison
% profile are exactly the same.
% We now find a corresponding Hartree velocity profile with pressure gradient
% and no suction or blowing.
% The comparison can be made for equal l, mT or H.
% Only the numbers 6 through 22 lead to a valid comparison because nr 1 through
% 5 and 23 have values for el, mT or H that are outside the range for Hartree
% profiles between stagnation point and separation.
% See chapter 4 of the report for details.
% Results for Hartree velocity profiles without suction or blowing follow from
% the function "find_Hartree" and the datafile Hartree_pg
clear
close all
% -----------------------------------------------------------------------------------
load Hartreetablezpg
load Hartree_pg
want_to_go_on=input('if you want to go on give 1 else give 0                  ')
while want_to_go_on==1 
nrprof=input('select a velocity profile with suction/blowing; 6<=nrprof<=22   ');
% ------------------------------------------------------------------------------------
if nrprof >=6 & nrprof <=22    
figure (1) % ----------------------------------------------------- figure 1 on
hold off
figure (2) % ----------------------------------------------------- figure 2 on
hold off
figure (3) % ----------------------------------------------------- figure 3 on
hold off
bign=501;  %     we calculate the boundary layer with a large number of points;
npar=input('indicate basis for comparison, 1=el; 2=mT; 3=H                  ');
etamax=aretamaxzpg(nrprof);
fwall=arf0zpg(nrprof);
fpp0=arfpp0zpg(nrprof);
el=arelzpg(nrprof);
mT=armTzpg(nrprof);
H=arbighzpg(nrprof);
betaa=0;
% -------------------------------------------------------------------------
[H,el,mT,u,shear,curve,y_bar]=find_Hartree(betaa,etamax,bign,fwall,fpp0);
% -------------------------------------------------------------------------
ep=max(find(u<.99));% ep=edge-point; we plot results for u<.99 only
%                    to avoid dividing by shear=0 at edge of boundary layer. 
% ------------------------------------------------
% We now calculate the critical Reynolds number according to Lin's approximation
% The location of the critical point is indicated by (+) in the various profiles.
Lin_value=.58/(pi*el);
Lin=-u(1:ep).*curve(1:ep)./(shear(1:ep).^3);
% In what follows we have assumed that "Lin" is a monotonic function of u. We have 
% never seen contradictory evidence but be aware of this. 
for m=1:bign
   if Lin(m)>2*Lin_value
      break
   end
end
nmax=m;
ccLin=spline(Lin(1:nmax),u(1:nmax),Lin_value);
Rcrit_Lin(nrprof)=25*el/ccLin^4;
y_bar_Lin=spline(u(1:ep),y_bar(1:ep),ccLin);
max_grid_point=max(find(y_bar<y_bar_Lin));
figure (1)  
plot(u(1:ep),y_bar(1:ep),'k',u(max_grid_point),y_bar(max_grid_point),'+k');
grid on
hold on
figure (2)  
plot(shear(1:ep),y_bar(1:ep),'k',shear(max_grid_point),y_bar(max_grid_point),'+k');
grid on
hold on
figure (3)  
plot(curve(1:ep),y_bar(1:ep),'k',curve(max_grid_point),y_bar(max_grid_point),'+k');
grid on
hold on
% We now determine the comparison Hartree profile without suction or blowing
% using the function "find_Hartree" and pre-computed input values beta and f"(0)
% taken from the data file "Hartree_pg" namely fsk_beta and fsk_fpp0
% For the comparison profile fwall=0
% We can take equal el (npar=1), equal mT (npar=2)or equal H (npar=3)
betaa_c=fsk_beta(nrprof,npar);
fpp0_c=fsk_fpp0(nrprof,npar);
fwall=0; % 4th input parameter=fwall=f"(0)
[H_c,el_c,mT_c,u_c,shear_c,curve_c,y_bar_c]=find_Hartree(betaa_c,etamax,bign,0,fpp0_c);
ep=max(find(u_c<.99));% ep=edge-point; we plot results for u_c<.99 only.
% ---------------------------------------------------------------------------------
% We now calculate the critical Reynolds number according to Lin's approximation
% The location of the critical point is indicated by (x) in the various profiles.
% ----------------------------------------------------------------------------------
clear Lin
Lin_value=.58/(pi*el_c);
Lin=-u_c(1:ep).*curve_c(1:ep)./(shear_c(1:ep).^3);
for m=1:bign
     if Lin(m)>2*Lin_value
        break
     end
 end
 nmax=m;
 ccLin=spline(Lin(1:nmax),u_c(1:nmax),Lin_value);
 Rcrit_Lincomp(nrprof)=25*el_c/ccLin^4;    
 y_bar_Lin=spline(u_c(1:ep),y_bar_c(1:ep),ccLin);
 max_grid_point=max(find(y_bar_c<y_bar_Lin));
 % ------------------------------------------------------------------------------
 text1=' equal el ';
 text2=' equal mT ';
 text3=' equal H ' ;
 text0='Flat plate with suction/blowing nr ';
 text4=int2str(nrprof);
 text5=' compared to Hartree profile with v0=0 at';
 % ------------------------------------------------------------------------------
 figure (1)  
 plot(u_c(1:ep),y_bar_c(1:ep),'k--',u_c(max_grid_point),y_bar_c(max_grid_point),'kx');
 xlabel('u/U')
 ylabel('y/theta')
 legend('actual','actual Lin point','comparison','comparison Lin point',2)   
 if npar==1
    aa=[text0 text4 text5 text1];
    title(aa)
 end
 if npar==2
    aa=[text0 text4 text5 text2];
    title(aa)
 end
 if npar==3
    aa=[text0 text4 text5 text3];
    title(aa)
 end
 shg
 disp ('view and/or print fig.1')
 disp ('type "return" to go to fig. 2')
 keyboard
 figure (2)  
 plot(shear_c(1:ep),y_bar_c(1:ep),'k--',shear_c(max_grid_point),y_bar_c(max_grid_point),'kx');
 xlabel('shear')
 ylabel('y/theta')
 legend('actual','actual Lin point','comparison','comparison Lin point',1)   
 if npar==1
    aa=[text0 text4 text5 text1];
    title(aa)
 end
 if npar==2
    aa=[text0 text4 text5 text2];
    title(aa)
 end
 if npar==3
    aa=[text0 text4 text5 text3];
    title(aa)
 end
 shg
 disp ('view and/or print fig.2')
 disp ('type "return" to go to fig. 3')
 keyboard
 figure (3)  
 plot(curve_c(1:ep),y_bar_c(1:ep),'k--',curve_c(max_grid_point),y_bar_c(max_grid_point),'kx');
 xlabel('curvature')
 ylabel('y/theta')
 legend('actual','actual Lin point','comparison','comparison Lin point',2)   
 if npar==1
    aa=[text0 text4 text5 text1];
    title(aa)
 end
 if npar==2
    aa=[text0 text4 text5 text2];
    title(aa)
 end
 if npar==3
    aa=[text0 text4 text5 text3];
    title(aa)
 end
 disp ('Re_theta_crit according to Lin')
 nrprof
 Rcrit_actual_profile=Rcrit_Lin(nrprof)
 Rcrit_comparison_profile=Rcrit_Lincomp(nrprof)
 shg
 disp ('view and/or print fig.3')
 disp ('type return to proceed')
 keyboard
 else
    disp('number of profile outside permissible range')
 end % if number of profile is permissible
 want_to_go_on=input('if you want to go on give 1 else give 0   ')
 end % while want to go on
 close all
 

