function Tss_local=cross_cut(Rt,H)   % (CD-ROM version)
% Function to find the cross section in Tss form of the stability diagram for
% arbitrary values of H (and hence of R-theta-crit) and Reynolds-theta.
% The m-file interpolates in a dataset that was derived from Arnal's tables 
% by scaling and shifting in such a way that interpolation becomes easy and 
% accurate. See chapters 6 and 10 of the report.
% The value of 10Log(Rtheta-crit) is found from a spline in log10(H).
% In this way T can be determined for a series of frequencies at a certain x-station.
% Repeating this procedure at a number of x-stations allows to compute the n-factor
% for each frequency.At each x-station the maximum n-factor gives N.
% A trace of the stability characteristics of the boundary layer can be plotted in a
% "road map" by the calling program. Sometimes the trace leaves the region covered by 
% the Arnal data.It is advised to check this roadmap to keep an eye on the 
% credibility of the extrapolated stability data.
% The roadmap shows a curve for N-factor=9 for the Hartree-Stewartson similar flows.
% These flows trace horizontal lines in the road map. Observe that the curve
% for N=9 is not necessarily valid for non-similar flows.  
% Make sure that in the main program the necessary stability data were loaded
% by executing "load datafile_for_n_factor" 
% Reynolds-theta should be given as a value for "Rt" in the calling program
% Also the value of the shape factor H should be provided.
% The following global statement may contain more variables then are really needed for 
% the present function because we kept the globals the same for most m-files.
% ------------------------------------------------------------------------------------
global ...
ArMaxMaxT ArlogRtcrit r_grid Tbar Tss domega_saved dome  ... 
logFax logMaxMaxT_vs_logcrit_spline logcrit_vs_logH_spline rtop_vs_logcrit_spline ... 
scale_domega_vs_logcrit_spline ycentre_spline slope_left_vs_logcrit_spline   ... 
ArNumberofReynolds ArH  Arscomega Arr omega_Arnal T_Arnal ome_ax fnr ri logcriti ... 
omega_at_axis log_Ftop_spline scomega TMax TMaxMax omegatop ... 
% ------------------------------------------------------------------end global-------
logRt=log10(Rt);   
logH=log10(H); 
logcrit_stag=ArlogRtcrit(1);
logcrit15=ArlogRtcrit(15);
log_Ftop_stag=ppval(log_Ftop_spline,logcrit_stag); 
logcriti=ppval(logcrit_vs_logH_spline,logH);
log_Ftop_i=ppval(log_Ftop_spline,logcriti); 
% -----------------------------------------------------------------------------------
if logcriti>=ArlogRtcrit(6) % This statement determines the slope of Log10(Faxis)
   slope_right=-sqrt(2);    % at the right-hand side of the roadmap.Different for
else                        % velocity profiles with (icase>6) or without (icase <=6)
   slope_right=-1;          % an inflexion point.
end
% ----------------------------------------------------------------------------------
logMaxMaxT=ppval(logMaxMaxT_vs_logcrit_spline,logcriti);
TMaxMax=10^logMaxMaxT;
scomega=ppval(scale_domega_vs_logcrit_spline,logcriti);
ri=logRt-logcriti;
% -----------------------------------------------------------------------------------
% Interpolation will be done with 3 values for r and 3 values for 10LogRtheta_crit 
% First we locate 3 points in the r_grid 
% Only points within or at the boundary of region 5 are used. See figure below.
% Outside region 5 extrapolations are used.
% -----------------------------------------------------------------------------------
if ri<=0
   nr2=2;
else
   nr2=max(find(r_grid <= ri));   
end
if nr2>58
   nr2=58;
end
if (ri-r_grid(nr2)) > .5*(r_grid(nr2+1)-r_grid(nr2))      % to find the nearest point
    nr2=nr2+1;
end
if nr2<=2
   nr2=2;
elseif nr2>=58   % All 3 points should be in the interval r_grid(1)=0 
   nr2=58;       % and r_grid(59)=2.5
end  
% -------------------------The same values for r are used at the 3 values for logcrit
nr3=nr2+1;nr1=nr2-1;
nr4=nr1;nr5=nr2;nr6=nr3;
nr7=nr1;nr8=nr2;nr9=nr3;
% now determine the icase values for interpolation and the corresponding logcrit values
icase_series=[1:15];
if logcriti>=ArlogRtcrit(2)
   icase2=2; 
elseif logcriti<=ArlogRtcrit(14)
   icase2=14;
else
   icase2=interp1(ArlogRtcrit,icase_series,logcriti,'nearest');
end   
%  --------------------All icase values should remain in the interval 1:15 -----------
if icase2<=2
   icase2=2;
elseif icase2>=14
   icase2=14;
end
icase1=icase2-1;icase3=icase2+1;
icase123=[icase1 icase2 icase3];
logcrit123=ArlogRtcrit(icase1:icase3);
logcrit1=logcrit123(1);
logcrit2=logcrit123(2);
logcrit3=logcrit123(3);
logcrit_array=[logcrit123 logcriti];
rtop=ppval(rtop_vs_logcrit_spline,logcrit_array);
rtop1=rtop(1);rtop2=rtop(2);rtop3=rtop(3);rtopi=rtop(4);
rbi=ri/rtopi;     
% -------------------------------------------------------------------------------------
r1=r_grid(nr1);r2=r_grid(nr2);r3=r_grid(nr3);
r4=r1;r5=r2;r6=r3;
r7=r1;r8=r2;r9=r3;
r1_9=[r1 r2 r3 r4 r5 r6 r7 r8 r9];
% We now have defined 9 points and are ready to interpolate using Lagrange_2d
% The points are not equally spaced, however the 3 r_values are the same in the 
% three rows
%
%    icase1 ----------- P1 ------- P2 ------  P3 ----------
%
%    icase2 ----------- P4 ------- P5 ------  P6 ----------
%
%    icase3 ----------- P7 ------- P8 ------  P9 ----------  
%
%                        |          |           |
%                    r1=r4=r7   r2=r5=r8    r3=r6=r9
%
% We treat different regions separately (see figure below); region 5 is the
% standard.
% At the boundaries of region 5 interpolation could have been done simpler by 
% 1-D Lagrange,but for clarity of the program it has been accepted that in some
% (not so often occurring) cases a number of zeros appear in the array of 
% interpolating coefficients.
% The 9 points are always inside or (at most 3 or 6 of them) on the boundary 
% of region 5
% For points outside region 5 special extrapolations are used, to be discussed later.
%
%                         |                            |
%                   1     |             2              |         3
%                         |                            |
%     H1=2.2160    -------A----------------------------B----------------------
%                         |                            |
%                   4     |         region 5           |         6 
%                         |                            |
%     H15=35.9440   ------C----------------------------D----------------------
%                         |                            |
%                   7     |             8              |         9
%                         E                            F
%                        r=0                         r=2.5
%
H1=ArH(1);     %= 2.2160
H15=ArH(15);   %=35.9440
% We first determine the region in which the point for later interpolation
% is located within or at the boundary of region 5. 
% Region 5 is the normal situation.If we look for a point outside region 5 we 
% arrive there later by extrapolation.
if ri>=0 & ri<=2.5 & H>=H1 & H<=H15   
   region=5;
   r_array=[r1_9 ri];
   logcrit_array=[logcrit123 logcriti];
   facs=lagrange_2d(r_array,logcrit_array);
elseif  H<H1 & ri<0
   region=1;
   r_array=[r1_9 0];% we first find Tss at point A and later shift to the left and up
   logcrit_array=[logcrit123 logcrit_stag];
   facs=lagrange_2d(r_array,logcrit_array);
elseif H<H1 & ri>=0 & ri<=2.5
   region=2; 
   r_array=[r1_9 ri];
   logcrit_array=[logcrit123 logcrit_stag];%we first find Tss at H1 (=along AB)and later 
   %                                        extrapolate upwards as described for the 
   %                                        asymptotic suction profile
   facs=lagrange_2d(r_array,logcrit_array);
elseif H<H1 & ri>2.5
   region=3;                 %We first find Tss at B and later shift to the right and up
   r_array=[r1_9 2.5];   
   logcrit_array=[logcrit123 logcrit_stag];
   facs=lagrange_2d(r_array,logcrit_array);
elseif ri<0 & H>=H1 & H<=H15
   region=4;                               %We first find Tss at AC and later shift left
   r_array=[r1_9 0]; 
   logcrit_array=[logcrit123 logcriti];
   facs=lagrange_2d(r_array,logcrit_array);
elseif H>=H1 & H<=H15 & ri>2.5
   region=6;                                   
   r_array=[r1_9 2.5];                   % we first find Tss at BD and later shift right
   logcrit_array=[logcrit123 logcriti];
   facs=lagrange_2d(r_array,logcrit_array);
elseif H>H15 & ri<0
   region=7;                  % We extrapolate linearly from icase=14 and 15 down at r=0 
   rrr=[r1 r2 r3 0];          % and shift later to the left
   facr=lagrange(rrr);      
   fact=(crit2-logcriti)/(logcrit2-logcrit3);
   facs(1)=0;
   facs(2)=0;
   facs(3)=0;
   facs(4)=(1-fact)*facr(1);
   facs(5)=(1-fact)*facr(2);
   facs(6)=(1-fact)*facr(3);
   facs(7)=fact*facr(1);
   facs(8)=fact*facr(2);
   facs(9)=fact*facr(3);
elseif H>H15 & ri>=0 & ri<=2.5
   region=8 ;                        % We find Tss at H15 (=along CD) by interpolation 
   rrr=[r1 r2 r3 ri];                % in the r_grid and extrapolate linearly from    
   facr=lagrange(rrr);               % icase=14 and 15 down
   fact=(logcrit2-logcriti)/(logcrit2-logcrit3);
   facs(1)=0;
   facs(2)=0;
   facs(3)=0;
   facs(4)=(1-fact)*facr(1);
   facs(5)=(1-fact)*facr(2);
   facs(6)=(1-fact)*facr(3);
   facs(7)=fact*facr(1);
   facs(8)=fact*facr(2);
   facs(9)=fact*facr(3);
else
   region=9;              % We extrapolate linearly from icase=14 and 15 down at r=2.5 
   rrr=[r1 r2 r3 2.5];    % and shift later to the right
   facr=lagrange(rrr);
   fact=(logcrit2-logcriti)/(logcrit2-logcrit3);
   facs(1)=0;
   facs(2)=0;
   facs(3)=0;
   facs(4)=(1-fact)*facr(1);
   facs(5)=(1-fact)*facr(2);
   facs(6)=(1-fact)*facr(3);
   facs(7)=fact*facr(1);
   facs(8)=fact*facr(2);
   facs(9)=fact*facr(3);
end
% -----------------------------------------------------------------------------------
% We now have the Lagrange interpolation factors to find Tss as follows.
% For region 1 at A
% For region 2 at AB and r
% For region 3 at B
% For region 4 at AC and logcriti
% For region 5 within ABDC and at ri and logcriti
% For region 6 at BD and logcriti
% For region 7 at CE and logcriti
% For region 8 at r and logcriti
% For region 9 at DF and logcriti
% ----------------------------------------------------------------------------------
% Now follows the 2d Lagrange interpolation

Tss_local=facs(1)*Tss{icase1,nr1}+facs(2)*Tss{icase1,nr2}+ ...
          facs(3)*Tss{icase1,nr3}+facs(4)*Tss{icase2,nr4}+ ...
          facs(5)*Tss{icase2,nr5}+facs(6)*Tss{icase2,nr6}+ ...
          facs(7)*Tss{icase3,nr7}+ facs(8)*Tss{icase3,nr8}+ ...
          facs(9)*Tss{icase3,nr9};
Tss_local=rectify_Tss(Tss_local);
       
log10Fax=facs(1)*logFax(icase1,nr1)+ ...
         facs(2)*logFax(icase1,nr2)+ ...
         facs(3)*logFax(icase1,nr3)+ ...
         facs(4)*logFax(icase2,nr4)+ ...
         facs(5)*logFax(icase2,nr5)+ ...
         facs(6)*logFax(icase2,nr6)+ ...
         facs(7)*logFax(icase3,nr7)+ ...
         facs(8)*logFax(icase3,nr8)+ ...
         facs(9)*logFax(icase3,nr9);
           
 TMax=facs(1)*Tbar(icase1,nr1)+ ...  % Note that Tbar and hence TMax is T at the  
      facs(2)*Tbar(icase1,nr2)+ ...  % axis divided by TMaxMax
      facs(3)*Tbar(icase1,nr3)+ ...
      facs(4)*Tbar(icase2,nr4)+ ...
      facs(5)*Tbar(icase2,nr5)+ ...
      facs(6)*Tbar(icase2,nr6)+ ...
      facs(7)*Tbar(icase3,nr7)+ ...
      facs(8)*Tbar(icase3,nr8)+ ...
      facs(9)*Tbar(icase3,nr9);
      
% We now make the final adjustments per region -----------------------------------
switch region  % -----------------------------------------------------------------
case 1  % Is for region 1 etc.----------------------------------------------------
    TMax=rbi*exp(1-rbi);   % We use the analytical approximation for r<0
    sl=ppval(slope_left_vs_logcrit_spline,logcrit_stag);% The axis in log form is  
                                                        % extrapolated linear to the 
                                                   % left with the appropriate slope
    log10Fax=log10Fax+ri*sl;
    log_Ftop_i=ppval(log_Ftop_spline,logcriti);
    log10Fax=log10Fax-log_Ftop_stag+log_Ftop_i;
 case 2 % ------------------------------------------
    log_Ftop_i=ppval(log_Ftop_spline,logcriti); 
    log10Fax=log10Fax-log_Ftop_stag+log_Ftop_i;               
 case 3 % ---------------------------------------------
    a=2.5/rtopi;
    aa=a*exp(1-a)  % to keep T-bar continuous across r=2.5
    TMax=TMax*rbi*exp(1-rbi)/aa;   
    log10Fax=log10Fax+(ri-2.5)*slope_right;% extrapolate axis with slope -1 or -sqrt(2)
    log_Ftop_i=ppval(log_Ftop_spline,logcriti);
    log10Fax=log10Fax-log_Ftop_stag+log_Ftop_i;    % extrapolate upwards
 case 4 % -----------------------------------------------
    TMax=rbi*exp(1-rbi);   
    sl=ppval(slope_left_vs_logcrit_spline,logcriti);
    log10Fax=log10Fax+ri*sl;
 case 5  % -------------------------------------------------
    % no further action needed     
 case 6  % -------------------------------------------------
    a=2.5/rtopi;
    aa=a*exp(1-a)
    TMax=TMax*rbi*exp(1-rbi)/aa;  % As in region 3,but only extrapolation to the right.
    log10Fax=log10Fax+(ri-2.5)*slope_right;
 case 7  % -----------------------------------------------------
    TMax=rbi*exp(1-rbi);   
    sl=ppval(slope_left_vs_logcrit_spline,logcrit15);
    log10Fax=log10Fax+ri*sl;
 case 8  % ----------------------------------------------------
         % no further action needed    
 case 9  % ----------------------------------------------------
    TMax=96.4274*TMax*rbi*exp(1-rbi);   
    log10Fax=log10Fax+(ri-2.5)*slope_right;
 end              %for switch region   ------------------------
 
 Fax=10^log10Fax;   
 omega_at_axis=Fax*Rt;
 % Note that Tss_local after the above interpolation should remain the 
 % MATLAB representation (for the version used)of a spline. Certain elements
 % that should be integers, although having retained their values,may have
 % become classified as floating point numbers after the interpolation.
 % Furthermore we defined the splines such that the ends left and right should 
 % be linear to avoid problems if occasionally extrapolation far outside the
 % definition range of the splines should occur.This linearity should also remain
 % after extrapolation.
 % Both aspects are taken care off bij the function "rectify" 
 
 
 
  
