function [aa_left,aa_right]=cross_cut_fast(Rt,H)% (CD-ROM version)
% Function to find the cross section in parabolic form of the stability diagram
% for arbitrary values of H (and hence of R-theta-crit) and Reynolds-theta. 
% See chapter 11 of the report.
% The value of 10Log(Rtheta-crit) is found from coefs for a spline in log10(H).
% In this way T can be determined for a series of frequencies at a certain x-station
% in the calling program. Repeating this procedure at a number of x-stations allows 
% to compute the n-factor for each frequency.
% At each x-station the maximum n-factor gives N.
% A trace of the stability characteristics of the boundary layer can be plotted in a
% "road map" by the calling program. Sometimes the trace leaves the region covered by 
% the Arnal data.It is advised to check this roadmap to keep an eye on the credibility
% of the extrapolated stability data.
% The roadmap shows a curve for N-factor=9 for the Hartree-Stewartson similar flows.
% These flows trace horizontal lines in the road map. Observe that the curve
% for N=9 is not necessarily valid for non-similar flows.  
% Make sure that in the main program the necessary stability data were loaded
% by executing "load datafile_for_n_factor".
% Reynolds-theta should be given as a value for "Rt" in the main program.
% Also the value of the shape factor H should be provided.
% The following global statement may contain more variables then are really needed for 
% the present function because we kept the global statement the same for a number 
% of m-files.
% ----------------------------------------------------------------------------------
global ... 
ArMaxMaxT ArlogRtcrit r_grid Tbar Tss domega_saved dome  ... 
logFax logMaxMaxT_vs_logcrit_spline logcrit_vs_logH_spline rtop_vs_logcrit_spline ... 
scale_domega_vs_logcrit_spline  ycentre_spline  slope_left_vs_logcrit_spline ... 
ArNumberofReynolds ArH  Arscomega Arr omega_Arnal T_Arnal ome_ax fnr ri logcriti ... 
omega_at_axis log_Ftop_spline scomega TMax TMaxMax omegatop ...  
pp_overall_left  pp_overall_right ...
coefs_log_Ftop  coefs_log_MaxMaxT   coefs_scale ...
coefs_rtop  coefs_slope_left  coefs_logcrit_vs_logH ...
breaks_log_Ftop  breaks_logMaxMaxT   breaks_scale ...
breaks_rtop  breaks_slope_left breaks_logcrit_vs_logH 
% --------------------------------------------------------------------- end global 
logRt=log10(Rt);   
logH=log10(H); 
% -----------first find logcriti; result should be the same as in cross_cut ------
xx=logH;
h=.005; %  =interval for logH; 1/h=200
n=floor(200*(xx-.25));    % n is the number of complete intervals to the left of xx
if n<0
   n=0;
end
if n>300
   n=300;
end
t=xx-n*h-.25;
t2=t*t;
t3=t2*t;
coefspol=coefs_logcrit_vs_logH(n+1,:);
logcriti=coefspol(1)*t3+coefspol(2)*t2+coefspol(3)*t+coefspol(4);

% ---------------now find other parameters from the splines in logcriti -------------
xx=logcriti;
h=.02;   % =interval length in logcriti 1/h=50 Is the same for all following splines
n=floor(50*(xx+1));        % n is the number of complete intervals to the left of xx
if n<0
   n=0;
end
if n>300
   n=300;
end
t=xx-n*h+1;
t2=t*t;
t3=t2*t;

coefspol=coefs_log_Ftop(n+1,:);
log_Ftop_i=coefspol(1)*t3+coefspol(2)*t2+coefspol(3)*t+coefspol(4);

coefspol=coefs_log_MaxMaxT(n+1,:);
logMaxMaxT=coefspol(1)*t3+coefspol(2)*t2+coefspol(3)*t+coefspol(4);

coefspol=coefs_scale(n+1,:);
scomega=coefspol(1)*t3+coefspol(2)*t2+coefspol(3)*t+coefspol(4);

coefspol=coefs_rtop(n+1,:);
rtop=coefspol(1)*t3+coefspol(2)*t2+coefspol(3)*t+coefspol(4);

slope=-sqrt(2);  % This is a rather bold approximation. Should be OK for all
% icase <=6 and for the other ones for r< r_top (=1/3). For the intended applications 
% this is assumed to be sufficiently accurate.
% Future versions may be changed. Please check the web site mentioned on the CD-ROM.

TMaxMax=10^logMaxMaxT;
ri=logRt-logcriti;
rib=ri/rtop;
TMax=rib*exp(1-rib);
log10Fax=log_Ftop_i+slope*(ri-1/3);
Fax=10^log10Fax;
omega_at_axis=Fax*Rt;
if ri<0
   aa_left=-1.0482;
   aa_right=-1.1518;
else
   aa_left =polyval(pp_overall_left ,ri);
   aa_right=polyval(pp_overall_right,ri);
end

 
 

  
