function [H,el,mT,u,shear,curve,y_bar]=find_Hartree(betaa,etamax,bign,fwall,fpp0)
% (CD-ROM version)
% find_Hartree determines the (attached) Hartree velocity profile for given values
% of beta, etamax, bign and fpp0
% These values should be taken from pre-calculated splines or tables so that no 
% shooting process is required. 
eta=linspace(0,etamax,bign);
em=betaa/(2-betaa);
a1=(em+1)/2;a2=em;a3=-a1+2*a2;a4=a3-a1;a5=a4-a1;a6=2*a3+a4;
a7=a5-a1;a8=a5+a6;a9=a7-a1;a10=a7+a8;a11=a8+2*a6;
h=etamax/(bign-1);
h1=h;h2=h1*h/2;h3=h2*h/3;h4=h3*h/4;h5=h4*h/5;h6=h5*h/6;
h7=h6*h/7;h8=h7*h/8;
f1=0;f2=fpp0;f0=fwall;
for n=1:(bign-1)
    f3=-a1*f0*f2-a2+a2*f1*f1;
    f4=-a1*f0*f3+a3*f1*f2;
    f5=-a1*f0*f4+a4*f1*f3+a3*f2*f2;
    f6=-a1*f0*f5+a5*f1*f4+a6*f2*f3;
    f7=-a1*f0*f6+a7*f1*f5+a8*f2*f4+a6*f3*f3;
    f8=-a1*f0*f7+a9*f1*f6+a10*f2*f5+a11*f3*f4;
    u(n)=f1;
    shear(n)=f2;
    curve(n)=f3;
    %f0 through f8 and u(n) are values at beginning of the step
    % now find f0,f1 and f2 at the end of the step using Taylor series
    f0=f0+f1*h1+f2*h2+f3*h3+f4*h4+f5*h5+f6*h6+f7*h7+f8*h8;
    f1=f1+h1*f2+h2*f3+h3*f4+h4*f5+h5*f6+h6*f7+h7*f8;
    f2=f2+h1*f3+h2*f4+h3*f5+h4*f6+h5*f7+h6*f8;
 end  
 % we now have f0, f1 and f2 at the end of the last step.
 u(bign)=f1;
 uinf=f1;
 shear(bign)=f2;
 curve(bign)=0;     % forced to 0
 fmax=f0;
 f3wall=-a1*fwall*fpp0-a2;
 dstar=etamax-fmax+fwall;
 theta=fmax*2*em-(3*em+1)*fwall-2*em*etamax+2*fpp0;% see explanation below
 theta=theta/(3*em+1);
 % ----------------------------------------------------------------------------------
 % Explanation of the procedure to calculate the Hartree profile
 % ----------------------------------------------------------------------------------
 % The Hartree velocity profile is calculated using a Taylor series solution. 
 % Shooting is not necessary because we pre-calculated a set of solutions and 
 % obtain the starting value of f''(0) from relevant splines or tables.
 % The Talor series includes terms of h^8 and is based on equation (3.39)in the report.
 % Higher derivatives are easily obtained by differentiating this equation 
 % a number of times. 
 % For the Hartree boundary layers displacement thickness and momentum loss thickness 
 % can be obtained by analytical integration. At first sight the equation used for 
 % theta may not be obvious.You have to integrate u*(1-u) or u and u^2 or f' and (f')^2
 % For the second integral first solve equation (3.39)for (f')^2 and then apply 
 % partial integration.  
 % -------------------------------------------------------------------------------------
 mT=f3wall*theta^2;
 H=dstar/theta;
 el=fpp0*theta;
 y_bar=eta/theta;
 shear=shear*theta;
 curve=curve*theta^2;
% end of function find_Hartree 






























