% logF_stability_diagrams.m   CD-ROM version
% This m-file generates stability diagrams in the form where frequencies
% are plotted as 10Log(F), where F=omega*nu/U^2
% This form is better suited for extrapolations to higher Reynolds numbers.
% For profiles with an inflexion point (icase>6) the influence of Rayleigh
% instability starts to show up; first at the higher Reynolds numbers.
% Rayleigh instability shows slope=-1 for the upper branch and for the axis.
% Note that this form can not be used for the lower branch at the higher 
% Reynolds numbers for icase>6 because here omega<0 and logF becomes complex.
% Also small irregularities near omega=0 tend to be exagerated when using the
% log scale. We accept these irregularities; they seem to be harmless.
% You can specify a series of values for icase to be viewed.
% For the horizontal axis we use r=10log(Rtheta)-10log(Rtheta crit).
clear
close all
load datafile_for_n_factor 
hold off
disp('You can specify a series of values for icase to be viewed             ');
disp('Give vales of icase, example [1 3 7] or [1:3]                         ');
icase_values=input('Give the array of icase_values                          ')
disp('You may return the program to "keyboard" if you want to print         ')
disp('intermediate results or you may pause for n seconds to view the figure') 
% --------------------------------------------------------------------------------
want_to_view=input('To view for n seconds give n (>0)or stop to print (give 0)  ');
% -----------------------------------------------------------------------------------
% For higher icase and Rtheta omega for the lower neutral curve can become <0
% We have to exclude these points for the log version.
% Maximum permissable numbers for the lower neutral curve are as follows:
max_nr_Arnal=[13 13 15 18 16 15 16 17 17 17 18 8 5 8 8];  % for the 15 icase values
max_nr_Tss=[59 59 59 59 59 59 59 59 59 59 59 38 33 30 27];% these are the max r_grid 
                                                          % points
for icase=icase_values
   nrmax=ArNumberofReynolds(icase);% = the number of cross sections for this icase.
   scale=Arscomega(icase);
   crit=ArlogRtcrit(icase);
   % ---------------------------------------------------------------------------------
   % first we draw the neutral curve directly from the Arnal data;indicated by symbols
   % ---------------------------------------------------------------------------------
   x_plot=Arr(icase,1:nrmax);
   logRt=x_plot+crit;
   ya=log10(ome_ax(icase,1:nrmax))-logRt;
   yh=log10(ome_neutral_high(icase,1:nrmax))-logRt;
   plot(x_plot,ya,'+',x_plot,yh,'o')
   grid on
   hold on
   nrm=max_nr_Arnal(icase);
   yl=log10(ome_neutral_low(icase,1:nrm))-logRt(1:nrm);
   xpl=x_plot(1:nrm);
   plot(xpl,yl,'o')
   clear x yl ya yh
   % ---------------------------------------------------------------------------------
   % now we draw the neutral curves by continuous lines from the data base 
   % ---------------------------------------------------------------------------------
   logRt=r_grid+crit;
   Rt=10.^logRt;
   ya=logFax(icase,:);
   omax=Rt.*10.^ya;
   yh=log10(neutr_Tss_high(icase,:)*scale+omax)-logRt;
   x_plot=r_grid;
   plot(x_plot,ya,x_plot,yh);
   nrm=max_nr_Tss(icase);
   yl=log10(neutr_Tss_low(icase,1:nrm)*scale+omax(1:nrm))-logRt(1:nrm);   
   xpl=x_plot(1:nrm);
   plot(xpl,yl)
   text1=['neutral curve in Log(F) format, icase= 'int2str(icase) ', symbols=Arnal'];
   title(text1);
   xlabel('r=10Log(Re theta)-10Log(Re theta crit)');
   ylabel('F=omega *nu/U^2');
   legend('axis','upper branch','lower branch','data base')
   clear yl ya yh 
   shg
   if want_to_view==0 
      disp ('Command has been returned to keyboard so that ')
      disp ('you may print the figure                      ')
      disp ('To resume program execution type "return"     ')
      keyboard
   else
      pause(want_to_view)
   end
   hold off
end % for icase ------------------------------------------------------------------------
keyboard
close all

       