% make_asuc_diagram.m    CD-ROM version
% This m-file is based on the results of "make_icase_from_1.m"
% It is now assumed that the scaled and shifted diagram for the
% asymptotic suction profile is equal to that for the Hartree 
% stagnation point profile. 
% By de-scaling and de-shifting with the extrapolated values 
% (using the appropriate splines)we find the diagram.
% ---------------------------------------------------------------
% The stagnation point (icase=1) wil be denoted by "1" or "stag"
% The asymptotic suction profile will be denoted by "asuc"
% ---------------------------------------------------------------
clear                                       % clear all variables
load datafile_for_n_factor
close all                                   % close all figures 
orient portrait
scale1=Arscomega(1);                        % scale for stag
logcrit_stag=ArlogRtcrit(1);
logcrit_asuc=ppval(logcrit_vs_logH_spline,log10(2));
logcrit_arr=[logcrit_stag logcrit_asuc];
scale=ppval(scale_domega_vs_logcrit_spline,logcrit_asuc);% scale for asuc
rfortop1=Arrtop(1);                                      % rtop for stag
rfortop=ppval(rtop_vs_logcrit_spline,logcrit_asuc); % rtop for asuc
yfine=linspace(-2,3,251);% 
T_values=[0 .25 .50 .60 .70 .80 .90 .95]; %= selected values of T/TMaxMax 
nr_T_values=length(T_values);             %  for contours.
center=ppval(log_Ftop_spline,logcrit_arr);%  logFtop for:
center_stag=center(1);                    %               stag
center_asuc=center(2);                    %               asuc
dcenter=center_asuc-center_stag; % Shift for the whole axis in logF form  
logFaxis_stag=logFax(1,:);       % For stag
logFaxis=logFaxis_stag+dcenter;  % For asuc
logRt=r_grid+logcrit_asuc; % The shift is made at equal r; hence LogRt changes
Rt=10.^logRt;
Fax=10.^logFaxis;
omax=Fax.*Rt;                     % Axis in classical form for asuc
omax_spline=spline(r_grid,omax);
figure(1) % ---------------------- Will show the asuc diagram in classical form
plot(r_grid,omax,'k');             % First plot axis
grid on
hold on
% -----------------------------------------------------------------------------
% First we define the crossings for all contourlines for icase=1 
% We have to interpolate r as a function of Tbar; because of the double valued
% relation we have to treat r<rtop and r>rtop separately.
r_left=r_grid(1:27);% note that r_grid(27) is near the top for icase=1
r_right=r_grid(27:59);
Tb_left=Tbar(1,1:27);
spline_r_Tb_left=spline(Tb_left,r_left);
first_points=ppval(spline_r_Tb_left,T_values);
Tb_right=Tbar(1,27:59);
spline_r_Tb_right=spline(Tb_right,r_right);    % Note that the spline is based 
                                               % on r_grid(27:59). For very small  
last_points=ppval(spline_r_Tb_right,T_values); % T_values the results may be wrong
                                               % for r>r_grid(59) (=2.5). 
ylower=zeros(1,59);                            % These will not be used however.
yupper=zeros(1,59);
ylower_fine=zeros(1,181);
yupper_fine=zeros(1,181);
angle_fine=linspace(-pi,+pi,361);
% First we find points on the contours for all T_values at values of r_grid 
% Because of the oval shape of most contours we will later interpolate in
% polar coordinates in the shifted and scaled diagram with (rtop,0) as origin. 
% using "angle_fine"
for iT=1:nr_T_values
   Tcheck=T_values(iT);
   ylower=zeros(1,59);
   yupper=zeros(1,59);
   ylower_fine=zeros(1,181);
   yupper_fine=zeros(1,181);
   for nr=1:59
      x=r_grid(nr);
      TM=Tbar(1,nr);
      ppz=Tss{1,nr};
      zfine=ppval(ppz,yfine);
      zfine=zfine+TM;
      k=find(zfine>=Tcheck);
      if isempty(k)==0
         k1=min(k);
         if k1<=2
             k1=2;
         end
         k2=max(k);
         if k2>=250
            k2=250;
         end
         k3=k1-1;
         k4=k2+1;
         y1=yfine(k1); y2=yfine(k2);y3=yfine(k3);y4=yfine(k4);
         z1=zfine(k1); z2=zfine(k2); z3=zfine(k3);z4=zfine(k4);
         ztemp=[z3 z1];
         ytemp=[y3 y1];
         ylower(nr)=interp1(ztemp,ytemp,Tcheck); % is linear interp OK?
         ztemp=[z2 z4];
         ytemp=[y2 y4];
         yupper(nr)=interp1(ztemp,ytemp,Tcheck); 
      end % if
   end % nr
   m1=min(find(ylower<0));% note that m1 and m2 also apply to y upper
   m2=max(find(ylower<0));
   rplot_upper=[first_points(iT) r_grid(m1:m2)]; 
   rplot_lower=[rplot_upper last_points(iT)]; 
   rplot=[rplot_lower fliplr(rplot_upper)]-rfortop1;
   yplot_lower=[0-eps ylower(m1:m2) 0 ];
   yplot_upper=[0+eps yupper(m1:m2)];
   yplot=[yplot_lower  fliplr(yplot_upper)];
   [angle_plot,rad_plot]=cart2pol(rplot,yplot);
   rad_fine=spline(angle_plot,rad_plot,angle_fine);
   figure(2)              % Shows the interpolation in polar coordinates
   plot(angle_fine,rad_fine,angle_plot,rad_plot,'o')
   grid on
   hold on 
   [xnew,ynew]=pol2cart(angle_fine,rad_fine);
   rnew_plot=xnew+rfortop1;
   if rnew_plot(181)>2.5
      kk=find(rnew_plot>2.5);
      ir1=min(kk)-1;
      ir2=max(kk)+1;
   else
      ir1=181;
      ir2=181;
   end
   figure(3) % Will show the asuc diagram in shifted and scaled form
   plot(rnew_plot(1:ir1),ynew(1:ir1),'k')
   hold on
   plot(rnew_plot(ir2:361),ynew(ir2:361),'k')
   grid on
   hold on
   % We now prepare the plot in classical form
   omax_new=ppval(omax_spline,rnew_plot);
   ome_new=ynew*scale+omax_new;
   omax_top=ppval(omax_spline,rfortop);
   figure(1) %------------------------------------------------ classical form
   plot(rnew_plot(1:ir1),ome_new(1:ir1),'k')
   hold on
   plot(rnew_plot(ir2:361),ome_new(ir2:361),'k')
   grid on
   hold on
   plot(rfortop,omax_top,'ok');
end % ----------------------------------------------------------  end for iT
% --------------------------------------------------------------  Figure 1 still on.
xlabel ('r=10logRtheta-10logRthetacrit');
ylabel ('omega*theta/U');
title  ('Synthetic classical diagram for the asymptotic suction profile')
text (-.4,-1E-3,'level curves for Tbar= 0, .25, .50, .60, .70, .80, .90, .95, 1.00')
figure (2)% -------------------------- Shows the interpolation in polar coordinates
xlabel('angle')
ylabel('radial coordinate')
title ('Interpolation in polar coordinates')
figure (3) % ---------------------------- % To finish the shifted and scaled diagram
xlabel ('r=10logRtheta-10logRthetacrit');
ylabel ('omega shifted and scaled');
plot(rfortop,0,'o')
title  ('Shifted and scaled stability diagram for the asymptotic suction profile')
text (-.4,-1.25,'level curves for Tbar= 0, .25, .50, .60, .70, .80, .90, .95, 1.00')
% --------------------------------------
figure (1)
shg
disp('view and/or print fig.1 ')
disp('to go to fig.2 type "return" ')
keyboard
% --------------------------------------
figure (2)
shg
disp('view and/or print fig.2 ')
disp('to go to fig.3 type "return" ')
keyboard
% ----------------------------------------
figure (3)
shg
disp('view and/or print fig.3 ')
disp('to proceed type "return" ')
keyboard
% --------------------------------------------
close all