% make_icase_from_1    CD-ROM version
% This m-file composes the stability diagram for an arbitrary icase
% from the diagram for icase=1 (stagnation point).
% It is assumed that the scaled and shifted diagrams are equal for both cases.
% This is a very good approximation for icase=1:6, because these are all profiles 
% without inflexion points.
% For icase=7:15 there is an inflexion point and the approximation is less good.  
% By de-scaling and de-shifting with the scales for the chosen icase,we find the
% diagram.
% The results of this program suggested the making of the asymptotic suction diagram 
% using the program "make_asuc_diagram.m" There you may also find some additional 
% information.
clear
load datafile_for_n_factor
close all % figures 
orient portrait
disp('The program contains a list of T-values (non-dimensional for 0<=Tcheck<1)    ')
disp('You may change this list of course; the programmed list is chosen not to make')
disp('the diagram too crowded')
disp('You may now choose the requested icase, best from 1:6                        ')
disp('Choosing 1 will result in a self-reproduction of icase=1                     ')
disp('It is instructive also to try 7<=icase<=15; this will show that there is     ')
disp('only some approximation for small Reynolds numbers where Rayleigh instability')
disp('is not yet manifest')
icase=input('choose icase from 1 to 15   ')
%---------- we first collect the necessary data for icase=1 and the chosen icase -----
scale1=Arscomega(1);
scale=Arscomega(icase);
logcrit_stag=ArlogRtcrit(1);
logcrit=ArlogRtcrit(icase);
logcrit_arr=[logcrit_stag logcrit];
rfortop1=Arrtop(1);
rfortop=Arrtop(icase);
yfine=linspace(-2,3,251);
T_values=[0 .25 .50 .60 .70 .80 .90 .95];         %= values of T/TMaxMax for contours 
nr_T_values=length(T_values);
center=ppval(log_Ftop_spline,logcrit_arr);
center_stag=center(1);
center=center(2);
dcenter=center-center_stag;
logFaxis_stag=logFax(1,:);     % This is the log form of axis for icase=1
logFaxis=logFaxis_stag+dcenter;% This is the shift to the chosen icase; 
logRt=r_grid+logcrit;             
Rt=10.^logRt;
Fax=10.^logFaxis;
omax=Fax.*Rt;                   % Here we transfer to the (omega*theta/U) format
omax_spline=spline(r_grid,omax);% and plot the axis
figure(1)   % ------------------  Will show the diagram in the classical form
plot(r_grid,omax,'k');
grid on
hold on
% First we define the crossings for the contour with the axis for icase=1 
% Because r as a function of T is double valued we have to treat r<rtop and r>rtop 
% separately. Note that r_grid(27) is near the top.   
r_left=r_grid(1:27);  
r_right=r_grid(27:59);
Tb_left=Tbar(1,1:27); %Note that the spline is based on r_grid(1:27).   
spline_r_Tb_left=spline(Tb_left,r_left);
first_points=ppval(spline_r_Tb_left,T_values);
Tb_right=Tbar(1,27:59);
spline_r_Tb_right=spline(Tb_right,r_right);   %Note that the spline is based on 
%                                              r_grid(27:59).   
last_points=ppval(spline_r_Tb_right,T_values);%For very small T_values the result
%                                              may be wrong. 
ylower=zeros(1,59);                        %The result will not be used for r>2.5
yupper=zeros(1,59);
ylower_fine=zeros(1,181);
yupper_fine=zeros(1,181);
angle_fine=linspace(-pi,+pi,361);
% now we find points for all T_values 
for iT=1:nr_T_values
   Tcheck=T_values(iT);
   ylower=zeros(1,59);
   yupper=zeros(1,59);
   ylower_fine=zeros(1,181);
   yupper_fine=zeros(1,181);
   for nr=1:59
      x=r_grid(nr);
      TM=Tbar(1,nr);
      ppz=Tss{1,nr};
      zfine=ppval(ppz,yfine);
      zfine=zfine+TM;
      k=find(zfine>=Tcheck);
      if isempty(k)==0
         k1=min(k);
         if k1<=2
             k1=2;
         end
         k2=max(k);
         if k2>=250
            k2=250;
         end
         k3=k1-1;
         k4=k2+1;
         y1=yfine(k1); y2=yfine(k2);y3=yfine(k3);y4=yfine(k4);
         z1=zfine(k1); z2=zfine(k2); z3=zfine(k3);z4=zfine(k4);
         ztemp=[z3 z1];
         ytemp=[y3 y1];
         ylower(nr)=interp1(ztemp,ytemp,Tcheck); 
         ztemp=[z2 z4];
         ytemp=[y2 y4];
         yupper(nr)=interp1(ztemp,ytemp,Tcheck); 
      end % if
   end % ------------------------------------------------------------- for nr
   m1=min(find(ylower<0));         % note that m1 and m2 also apply to yupper
   m2=max(find(ylower<0));
   rplot_upper=[first_points(iT) r_grid(m1:m2)]; 
   rplot_lower=[rplot_upper last_points(iT)]; 
   rplot=[rplot_lower fliplr(rplot_upper)]-rfortop1;
   yplot_lower=[0-eps ylower(m1:m2) 0 ];
   yplot_upper=[0+eps yupper(m1:m2)];
   yplot=[yplot_lower  fliplr(yplot_upper)];
   [angle_plot,rad_plot]=cart2pol(rplot,yplot);
   rad_fine=spline(angle_plot,rad_plot,angle_fine);
   % Figure(3) Will contain the shifted and scaled diagram
   % In these variables we will also spline_interpolate the contour curves
   % Note that our assumption is that the shifted and scaled diagram is the same
   % for icase=1 and the other ones. The correspondence is better the closer
   % icase to 1
   % Figure 2 shows the splined radius values agains the angle (-pi to +pi);
   % Polar coordinates are used in the scaled and shifted diagram with (rtop,0) as 
   % origin. Angle=0 is the point most to the right          
   figure (2)  % ------------------------------------------------------------------       
   plot(angle_fine,rad_fine,angle_plot,rad_plot,'o')
   grid on
   hold on 
   [xnew,ynew]=pol2cart(angle_fine,rad_fine);
   rnew_plot=xnew+rfortop1;
   if rnew_plot(181)>2.5
      kk=find(rnew_plot>2.5);
      ir1=min(kk)-1;
      ir2=max(kk)+1;
   else
      ir1=181;
      ir2=181;
   end
   figure(3) %------------------------------ Will show the scaled and shifted diagram
   plot(rnew_plot(1:ir1),ynew(1:ir1),'k')
   hold on
   plot(rnew_plot(ir2:361),ynew(ir2:361),'k')
   grid on
   hold on
   % -------------------------------------------- We now convert to the classical form
   omax_new=ppval(omax_spline,rnew_plot);
   ome_new=ynew*scale+omax_new;
   omax_top=ppval(omax_spline,rfortop);
   figure(1)
   plot(rnew_plot(1:ir1),ome_new(1:ir1),'k')
   hold on
   plot(rnew_plot(ir2:361),ome_new(ir2:361),'k')
   grid on
   hold on
   plot(rfortop,omax_top,'ok');
end % for iT
figure(1) % ------------------------------------------------------classical form
nrmax=ArNumberofReynolds(icase);
rplot=r_grid;
% first we use symbols for the neutral curve directly from the Arnal data
for nr=1:nrmax
    x=Arr(icase,nr);
    if x>=0
       yl=ome_neutral_low(icase,nr);
       yh=ome_neutral_high(icase,nr);
       plot(x,yl,'+k',x,yh,'+k');
       hold on
    end   
end
grid on
hold on
% Now we draw points for all T_values directly interpolated from Arnal
for nr=1:nrmax
    x=Arr(icase,nr);
    y=omega_Arnal{icase,nr};% note that here we work directly in omega
    z=T_Arnal{icase,nr};
    max_ome=length(y);
    yfirst=y(1);
    ylast=y(max_ome);
    yfine=linspace(yfirst,ylast,251);
    zfine=spline(y,z,yfine);
    for Tcheck=T_values
        k=find(zfine>=Tcheck);
        if isempty(k)==0
           k1=min(k);
           if k1<=2
              k1=2;
           end
           k2=max(k);
           if k2>=250
              k2=250;
           end
           k3=k1-1;
           k4=k2+1;
           y1=yfine(k1); y2=yfine(k2);y3=yfine(k3);y4=yfine(k4);
           z1=zfine(k1); z2=zfine(k2); z3=zfine(k3);z4=zfine(k4);
           ztemp=[z3 z1];
           ytemp=[y3 y1];
           yleft=interp1(ztemp,ytemp,Tcheck); 
           ztemp=[z2 z4];
           ytemp=[y2 y4];
           yright=interp1(ztemp,ytemp,Tcheck); 
           ya=ome_ax(icase,nr);
           plot(x,yleft,'xk',x,yright,'xk',x,ya,'xk');
        end  % end if
        hold on
    end % end for Tcheck
 end     % for nr
 figure (1) %------------------------------------------------------- classical form
 xlabel ('r=10logRtheta-10logRthetacrit');
 ylabel ('omega*theta/U');
 title_text_1='Classical diagram for icase=';
 title_text_2='(symbols); curves derived from icase=1';
 title ([title_text_1  int2str(icase) title_text_2]);
 text (0,.1*ome_ax(icase,1),'curves for Tbar= 0, .25, .50, .60, .70, .80, .90, .95, 1.00')
 figure (2) % ----------------------------------------------------------------------------
 xlabel('angle')
 ylabel('radial distance')
 title('interpolation in polar coordinates around (rtop, 0)')
 figure (3) %------------------------------------ To finish the shifted and scaled diagram
 xlabel ('r=10logRtheta-10logRthetacrit');
 ylabel ('omega shifted and scaled');
 title_text_3='Shifted and scaled stability diagram for icase=';
 title  ([title_text_3  int2str(icase) ' derived from icase=1'])
 text (-.4,-1.25,'level curves for Tbar= 0, .25, .50, .60, .70, .80, .90, .95, 1.00')
 plot(r_grid(27),0,'o') 
 figure(3)
 disp ('------------------------------------------------------------------- ')
 disp ('This is the shifted and scaled diagram ')
 disp ('assumed to be equal for icase=1 and the present icase')
 disp ('To proceed type "return"      ')
 disp ( '------------------------------------------------------------------- ')
 keyboard
 figure (2)
 shg
 disp ('This figure shows the interpolation in polar coordinates ')
 disp ('around the top in the shifted and scaled diagram to complete the diagram')
 disp ('To proceed type "return"  ')
 disp ('--------------------------------------------------------------------------- ')
 keyboard
 figure (1)
 shg
 disp ('This is the resulting classic diagram for the present icase ')
 disp ('curves are derived from icase=1; the symbols are from Arnal for the present icase') 
 disp ('To proceed type "return"      ')
 keyboard
 close all
 
 
 
 
 
