% plot_stability_diagrams.m  (CD-ROM version)
% This m-file generates stability diagrams to compare the database results 
% to the Arnal data. Note the great similarity for the scaled and shifted diagrams 
% when icase=1:6 For these cases the velocity profiles do not have an inflexion point.
% For profiles with an inflexion point, that is icase>6 the influence of Rayleigh
% instability starts to show up; first at the higher Reynolds numbers.At the lower
% Reynolds numbers there is still a reasonable similarity.
% We will later use the observed similarity to extrapolate to H=2 
% (asymptotic suction profile) and to make a fast version of cross_cut.
clear
close all
load datafile_for_n_factor
ome_max_Arr=[.02 .02 .03 .04 .045 .06 .07 .09 .12 .15 .165 .15 .14 .10 .06];
% To set the upper boundary for the contour plot in figure 2.
figure (1)  % ---------------------- Will give the scaled and shifted diagram.
hold off
figure (2)  % ---------------------- Will give the classical form.
hold off
dom=domega_saved;
dom_fine=linspace(-2,3,251);
T_values=[0 .2 .4 .6 .8 .95];%[0 .05 .1 .2 .4 .6 .8 .9 .95]; % To define the
% contour lines. May be changed
res=99*ones(251,59); % to store data for contour plot from Tss
disp('you can specify a series of values for icase to be viewed           ')
disp('give vales of icase, example [1 3 7] or [1:3]                       ')
% --------------------------------------------------------------------------
icase_values=input('give the array of icase_values                        ')
% --------------------------------------------------------------------------
disp('to show the similarity of the diagrams, especially for icase=1:3    ')
disp('or even 1:6 you can superimpose the scaled and shifted diagrams     ')
disp('It is instructive to try also icase>6;note that some similarity     ')
disp('remains at the lower Reynolds numbers                               ')
% --------------------------------------------------------------------------
disp('After each icase command is returned to keyboard so that you may view')
disp('the results and/or print the figures')
disp('Program execution is resumed by typing "return" in the command window')
super_impose=input('give 1 for superposition; else give 0                 ')
% --------------------------------------------------------------------------
for icase=icase_values % ----------------------------start for icase -------
   disp('----------------------------------------------------------------- ')
   icase
   nrmax=ArNumberofReynolds(icase);
   rtop=Arrtop(icase);
   scale=Arscomega(icase);
   rplot=r_grid;
   rbar_plot=rplot/rtop;
   logcrit=ArlogRtcrit(icase);
   % We draw points for all T_values from Arnal 
      for nr=1:nrmax  % ------------------------------start for nr ---------
          x=Arr(icase,nr);
          x_bar=x/rtop;
          y=omega_Arnal{icase,nr};
          z=T_Arnal{icase,nr};
          max_ome=length(y);
          yfirst=y(1);
          ylast=y(max_ome);
          yfine=linspace(yfirst,ylast,251);
          zfine=spline(y,z,yfine);
        for Tcheck=T_values  % ------------------------start for Tcheck -----
          k=find(zfine>=Tcheck);
          if isempty(k)==0
             k1=min(k);
             if k1<=2
                k1=2;
             end
             k2=max(k);
          if k2>=250
             k2=250;
          end
          k3=k1-1;
          k4=k2+1;
          y1=yfine(k1); y2=yfine(k2);y3=yfine(k3);y4=yfine(k4);
          z1=zfine(k1); z2=zfine(k2); z3=zfine(k3);z4=zfine(k4);
          ppleft=polyfit([z3 z1],[y3 y1],1);
          yleft=polyval(ppleft,Tcheck);
          ppright=polyfit([z2 z4],[y2 y4],1);
          yright=polyval(ppright,Tcheck);
          ya=ome_ax(icase,nr);
          figure(1) 
          plot(x_bar,(yleft-ya)/scale,'+k',x_bar,(yright-ya)/scale,'+k');
          grid on
          hold on   
          figure (2)
          plot(x,yleft,'+k',x,yright,'+k',x,ya,'xk');
          grid on
          hold on   
          end % -----------------------------------------end if -----------------
        end   % ---------------------------------------- end for Tcheck ---------
      end     % -----------------------------------------end for nr  ------------
    figure (1)% -----------------------------------------------------------------
    plot(1,0,'ok') % for the top
    figure (2)% -----------------------------------------------------------------
    yaa=ome_ax(icase,1:nrmax);
    ytop=spline(Arr(icase,1:nrmax),yaa,rtop);
    plot(rtop,ytop,'ok')
    % --------------------------------------------------------------------
    % we now determine contour lines according to the data base method 
    % --------------------------------------------------------------------
    for nr=1:59
      xx=r_grid(nr);
      x_bar=xx/rtop;
      TM=Tbar(icase,nr);
      ppz=Tss{icase,nr};   
      z=ppval(ppz,dom_fine);
      z=z+TM;
      res(:,nr)=z';
    end   % for nr
    figure (1)% -------------------------------------------------------------
    contour(rbar_plot,dom_fine,res,T_values,'k')
    % ------------------------------------------------------------------------
    omega_max=ome_max_Arr(icase);
    om_fine=linspace(0,omega_max,251);
    for nr=1:59
       xx=r_grid(nr);
       logRt=xx+logcrit;
       Rt=10^logRt;
       Fax=10^logFax(icase,nr);
       omega_for_ax(nr)=Fax*Rt;
       domff=(om_fine-omega_for_ax(nr))/scale;
       TM=Tbar(icase,nr);
       x=xx/rtop;
       ppz=Tss{icase,nr};   
       z=ppval(ppz,domff);
       z=z+TM;
       res(:,nr)=z';
    end  % for nr
    figure (2)
    contour(rplot,om_fine,res,T_values,'k')
    plot(r_grid,omega_for_ax,'k') 
    omega_top=spline(r_grid,omega_for_ax,rtop);
    plot(rtop,omega_top,'ok')
    figure (1)
    if super_impose==1
      hold on
    else
      hold off
    end
    title('scaled and shifted diagram; symbols=Arnal; curves=database')
    xlabel('rbar=(10logRtheta-10logRthetacrit)/rtop')
    ylabel('omega scaled=(omega-omega axis)/scale')
    text1=['icase='int2str(icase)]; 
    text (4.1,1.25,'Tbar values=0  .2  .4  .6  .8  .95 ');
    text (6.1,-1.25,text1);
    disp (' --------------------------------------------------------------  ')
    disp('scaled and shifted diagram')
    if super_impose==1
       disp( 'diagrams will be superimposed')
    end
    disp ('---------------------------------------------------------------- ')
    shg
    keyboard
    figure (2)% -----------------------------------------------------------
    title('classic diagram; symbols=Arnal; curves=database')
    xlabel('r=10logRtheta-10logRthetacrit')
    ylabel('omega * theta/U')
    text1=['icase='int2str(icase)]; 
    text (1.5,.5*omega_max,'Tbar values=0  .2  .4  .6  .8  .95 ')
    text (1.5,.25*omega_max,text1)
    disp ( '--------------------------------------------------------------- ')
    disp('classic diagram')
    disp('------------------------------------------------------------------')
    shg
    keyboard   
    hold off
    end % for icase_values
    close all

