% principles_of_stab_diagr   (CD-ROM version)
% This m-file generates stability diagrams in the classical form 
% for 3 selected cases namely: icase=1 (beta=1); icase=6 (beta=0)
% and icase=11 (beta=-.198838; that is separation) 
% For the profile with an inflexion point(icase=11) the influence of Rayleigh
% instability shows up at the higher Reynolds numbers.
% Although the program text is largely the same for the three cases, we just
% repeated these parts for ease of programming, because the location for the texts 
% in the figures, titles, etc. are different.
% ---------------------------------------------------------------------------------
clear
clc
close all
load datafile_for_n_factor 
orient portrait
disp('After each icase we return the program to "keyboard"        ')
disp('Then you can view the figure and print it if you want       ')
disp('To resume program execution type "return"                   ')
% 
% -------------------------------- icase=1 ----------------------------------------
icase=1
hold off
nrmax=ArNumberofReynolds(icase);
crit=ArlogRtcrit(icase);
% -------------------------------------------------------
% we draw the neutral curve directly from the Arnal data 
% -------------------------------------------------------
x_plot=Arr(icase,1:nrmax)+crit;
yl=ome_neutral_low(icase,1:nrmax);
ya=ome_ax(icase,1:nrmax);
yh=ome_neutral_high(icase,1:nrmax);
xtop=Arrtop(icase)+crit;
ytop=spline(x_plot,ya,xtop);
ytop2=spline(x_plot,yh,xtop);
plot(x_plot,yl,'ok',x_plot,yh,'ok',x_plot,ya,'+k')
hold on
plot(x_plot,yl,'k',x_plot,yh,'k',x_plot,ya,'k')
plot(xtop,ytop,'sk',xtop,ytop2,'sk');
xmin=3;xmax=5;ymin=0;ymax=.02;
axis([xmin xmax ymin ymax]);
xxx=[crit  crit];
yyy=[ymin ymax];
plot(xxx,yyy,'--k')
grid off
text(crit,.001,'^{10}Log(R_{\theta-crit)}')
xx=[xtop xtop];
yy=[ytop ytop2];
plot(xx,yy,'--k');
text(xtop,.5*(ytop+ytop2),'scale');
text(xtop+.02,ytop,' top');
text(4.2,.0105,'axis');
text(4.2,.0145,'upper branch');
text(4.2,.0065,'lower branch');
xlabel('^{10}Log(R_{\theta })');
ylabel('omega * theta/U');
title('stability diagram for stagnation point (beta=1; icase=1)')
shg
keyboard
% ------------------------------------  
hold off
clear  yl ya yh
% ------------------- icase=6  -------------------------------------------------
icase=6
nrmax=ArNumberofReynolds(icase);
crit=ArlogRtcrit(icase);
% -------------------------------------------------------------------------------
% we draw the neutral curve directly from the Arnal data
% -------------------------------------------------------------------------------
x_plot=Arr(icase,2:nrmax)+crit;
yl=ome_neutral_low(icase,2:nrmax);
ya=ome_ax(icase,2:nrmax);
yh=ome_neutral_high(icase,2:nrmax);
xtop=Arrtop(icase)+crit;
ytop=spline(x_plot,ya,xtop);
ytop2=spline(x_plot,yh,xtop);
plot(x_plot,yl,'ok',x_plot,yh,'ok',x_plot,ya,'+k')
hold on
plot(x_plot,yl,'k',x_plot,yh,'k',x_plot,ya,'k')
plot(xtop,ytop,'sk',xtop,ytop2,'sk');
xmin=2;xmax=4;ymin=0;ymax=.06;
axis([xmin xmax ymin ymax]);
xxx=[crit  crit];
yyy=[ymin ymax];
plot(xxx,yyy,'--k')
grid off
text(crit,.0025,'^{10}Log(R_{\theta-crit)}')
xx=[xtop xtop];
yy=[ytop ytop2];
plot(xx,yy,'--k');
text(xtop,.5*(ytop+ytop2),'scale');
text(xtop+.02,ytop+.001,'top');
text(3.2,.021,'axis');
text(3.2,.032,'upper branch');
text(3.2,.009,'lower branch');
xlabel('^{10}Log(R_{\theta })');
ylabel('omega * theta/U');
title('stability diagram for flat plate (beta=0; icase=6)')
shg
keyboard
hold off
clear yl yh ya
% ------------------------ icase=11 ------------------------------
icase=11
nrmax=ArNumberofReynolds(icase);
crit=ArlogRtcrit(icase);
% -------------------------------------------------------------
% we draw the neutral curve directly from the Arnal data
% -------------------------------------------------------------
x_plot=Arr(icase,1:nrmax)+crit;
yl=ome_neutral_low(icase,1:nrmax);
ya=ome_ax(icase,1:nrmax);
yh=ome_neutral_high(icase,1:nrmax);
xtop=Arrtop(icase)+crit;
ytop=spline(x_plot,ya,xtop);
ytop2=spline(x_plot,yh,xtop);
plot(x_plot,yl,'ok',x_plot,yh,'ok',x_plot,ya,'+k')
hold on
plot(x_plot,yl,'k',x_plot,yh,'k',x_plot,ya,'k')
plot(xtop,ytop,'sk',xtop,ytop2,'sk');
xmin=1;xmax=3.5;ymin=0;ymax=.20;
axis([xmin xmax ymin ymax]);
xxx=[crit  crit];
yyy=[ymin ymax];
plot(xxx,yyy,'--k')
grid off
text(crit,.005,'^{10}Log(R_{\theta-crit)}')
xx=[xtop xtop];
yy=[ytop ytop2];
plot(xx,yy,'--k');
text(xtop,.5*(ytop+ytop2),'scale');
text(xtop+.02,ytop+.001,' top');
text(2.2,.067,'axis');
text(2.2,.165,'upper branch');
text(2.2,.007,'lower branch');
xlabel('^{10}Log(R_{\theta })');
ylabel('omega * theta/U');
title('stability diagram for separation profile (beta=-.198838; icase=11)')   
shg
keyboard
close all