% review_splines.m   (CD-ROM version)
% Shows the various splines for the Arnal data and in addition 
% the data for the asymptotic suction profile that are known or
% extrapolated.
%               H=2;
%               R_deltastar_crit=46270  (from Hughes & Reid,JFM)
%               R_theta_crit    =23135  ( same)
%               MaxMaxT         = .041  (extrapolated)
%               10Log(MaxMaxT)  =-1.3872
%               Log10(Ftop)     =-6.7507(extrapolated)
% Note that Ftop is F at axis for the average top taken at r_grid(27)=1/3
% With "log" we always mean 10Log
clear
close all
load datafile_for_n_factor
orient portrait
disp ('You may choose to pause and view a figure              ')
disp ('or to stop and return to keyboard to print a figure    ')
disp ('                                                       ')
% ----------------------------------------------------------------------------------
pause_or_print=input('give 0 for stop and print, give n>0 for n seconds pause    ');

% ------------------ ----------------logcrit_vs_logH_spline ------------------------
logcrit_asuc=log10(23135);
logH_asuc=log10(2);
MaxMaxT_asuc=.041;
Log_Ftop_asuc=-6.7507;
hold off
plot(ArlogH,ArlogRtcrit,'o',logH_asuc,logcrit_asuc,'+');
grid on
hold on
x_fine=linspace(.3,1.6,200);
y_fine=ppval(logcrit_vs_logH_spline,x_fine);
plot(x_fine,y_fine);
title('^{10}Log(R-theta-crit) vs ^{10}Log H')
legend('from Arnal','asymptotic suction','spline')
shg
if pause_or_print==0
   disp ('  ')
   disp ('You may print this figure ')
   disp ('To resume program execution type "return"    ')
   keyboard
else
   disp ('  ')
   disp ('pause-wait') 
   pause(pause_or_print)
end
legend off
hold off
clear x_fine y_fine

% -------------------------The inverse spline is logH_vs_logcrit_spline --------------
plot(ArlogRtcrit,ArlogH,'o',logcrit_asuc,logH_asuc,'+');
grid on
hold on
x_fine=linspace(-.5,4.5,200);             % remains the same for all following splines
y_fine=ppval(logH_vs_logcrit_spline,x_fine);
plot(x_fine,y_fine);
title('^{10}Log H vs ^{10}Log(R-theta-crit)')
legend('from Arnal','asymptotic suction','spline')
shg
if pause_or_print==0
   disp ('  ')
   disp ('You may print this figure ')
   disp ('To resume program execution type "return"    ')
   keyboard
else
   disp ('  ')
   disp ('pause-wait') 
   pause(pause_or_print)
end
legend off
hold off

% ---------------------------logMaxMaxT_vs_logcrit_spline------------------------------
plot(ArlogRtcrit,log10(ArMaxMaxT),'o')
hold on
grid on
plot(logcrit_asuc,log10(MaxMaxT_asuc),'+')
y_fine=ppval(logMaxMaxT_vs_logcrit_spline,x_fine);
plot(x_fine,y_fine);
title('^{10}Log(MaxMaxT) vs ^{10}Log(R-theta-crit)')
legend('from Arnal','asymptotic suction','spline')
shg
if pause_or_print==0
   disp ('  ')
   disp ('You may print this figure ')
   disp ('To resume program execution type "return"    ')
   keyboard
else
   disp ('  ')
   disp ('pause-wait') 
   pause(pause_or_print)
end
legend off
hold off

% -------------------------------- rtop_vs_logcrit_spline----------------------------- 
y_fine=ppval(rtop_vs_logcrit_spline,x_fine);
y_asuc=ppval(rtop_vs_logcrit_spline,logcrit_asuc);
plot(ArlogRtcrit,Arrtop,'o',logcrit_asuc,y_asuc,'+',x_fine,y_fine);
grid on
title('rtop vs ^{10}Log(R-theta-crit)')
legend('from Arnal','asymptotic suction','spline')
shg
if pause_or_print==0
   disp ('  ')
   disp ('You may print this figure ')
   disp ('To resume program execution type "return"    ')
   keyboard
else
   disp ('  ')
   disp ('pause-wait') 
   pause(pause_or_print)
end
legend off
hold off

%---------------------------- scale_domega_vs_logcrit_spline -------------------------
y_fine=ppval(scale_domega_vs_logcrit_spline,x_fine);
y_asuc=ppval(scale_domega_vs_logcrit_spline,logcrit_asuc);
plot(ArlogRtcrit,Arscomega,'o',logcrit_asuc,y_asuc,'+',x_fine,y_fine);
grid on
title('scale omega vs ^{10}Log(R-theta-crit)')
legend('from Arnal','asymptotic suction','spline')
shg
if pause_or_print==0
   disp ('  ')
   disp ('You may print this figure ')
   disp ('To resume program execution type "return"    ')
   keyboard
else
   disp ('  ')
   disp ('pause-wait') 
   pause(pause_or_print)
end
legend off
hold off

% -------------------------- log_Ftop_spline (=logFtop for grid(27)=1/3 )------------
FFF=(logFax(:,27))';
y_fine=ppval(log_Ftop_spline,x_fine);
y_asuc=ppval(log_Ftop_spline,logcrit_asuc);
plot(ArlogRtcrit,FFF,'o',logcrit_asuc,y_asuc,'+',x_fine,y_fine);
grid on
title('^{10}Log F for average top (at r=1/3) vs ^{10}Log(R-theta-crit)')
legend('from Arnal','asymptotic suction','spline')
shg
if pause_or_print==0
   disp ('  ')
   disp ('You may print this figure ')
   disp ('To resume program execution type "return"    ')
   keyboard
else
   disp ('  ')
   disp ('pause-wait') 
   pause(pause_or_print)
end
keyboard
close all
